@@ -36,7 +36,6 @@
 
 #include <KDatePicker>
 #include <KLocalizedString>
-
 #include <QApplication>
 #include <QDate>
 #include <QDesktopWidget>
@@ -46,25 +45,25 @@
 #include <QMouseEvent>
 #include <QVBoxLayout>
 
-AnnotationDialog::DateEdit::DateEdit( bool isStartEdit, QWidget *parent )
-    : QComboBox( parent ),
-      m_defaultValue( QDate::currentDate() ),
-      m_ReadOnly(false),
-      m_DiscardNextMousePress(false),
-      m_IsStartEdit( isStartEdit )
+AnnotationDialog::DateEdit::DateEdit(bool isStartEdit, QWidget *parent)
+    : QComboBox(parent)
+    , m_defaultValue(QDate::currentDate())
+    , m_ReadOnly(false)
+    , m_DiscardNextMousePress(false)
+    , m_IsStartEdit(isStartEdit)
 {
     setEditable(true);
-    setMaxCount(1);       // need at least one entry for popup to work
+    setMaxCount(1); // need at least one entry for popup to work
     m_value = m_defaultValue;
-    QString today = QDate::currentDate().toString( QString::fromLatin1("dd. MMM yyyy") );
-    addItem(QString::fromLatin1( "" ) );
+    QString today = QDate::currentDate().toString(QString::fromLatin1("dd. MMM yyyy"));
+    addItem(QString::fromLatin1(""));
     setCurrentIndex(0);
-    setItemText( 0, QString::fromLatin1( "" ));
+    setItemText(0, QString::fromLatin1(""));
     setMinimumSize(sizeHint());
 
     m_DateFrame = new QFrame;
     m_DateFrame->setWindowFlags(Qt::Popup);
-    QVBoxLayout* layout = new QVBoxLayout(m_DateFrame);
+    QVBoxLayout *layout = new QVBoxLayout(m_DateFrame);
     m_DateFrame->setFrameStyle(QFrame::StyledPanel | QFrame::Raised);
     m_DateFrame->setLineWidth(3);
     m_DateFrame->hide();
@@ -73,8 +72,8 @@ AnnotationDialog::DateEdit::DateEdit( bool isStartEdit, QWidget *parent )
     m_DatePicker = new KDatePicker(m_value, m_DateFrame);
     layout->addWidget(m_DatePicker);
 
-    connect(lineEdit(),&QLineEdit::editingFinished,this,&DateEdit::lineEnterPressed);
-    connect(this,&QComboBox::currentTextChanged,this,&DateEdit::slotTextChanged);
+    connect(lineEdit(), &QLineEdit::editingFinished, this, &DateEdit::lineEnterPressed);
+    connect(this, &QComboBox::currentTextChanged, this, &DateEdit::slotTextChanged);
 
     connect(m_DatePicker, &KDatePicker::dateEntered, this, &DateEdit::dateEntered);
     connect(m_DatePicker, &KDatePicker::dateSelected, this, &DateEdit::dateSelected);
@@ -86,12 +85,11 @@ AnnotationDialog::DateEdit::DateEdit( bool isStartEdit, QWidget *parent )
     m_KeywordMap[i18n("yesterday")] = -1;
 
     QString dayName;
-    for (int i = 1; i <= 7; ++i)
-    {
-        dayName = QLocale().dayName(i,QLocale::LongFormat).toLower();
+    for (int i = 1; i <= 7; ++i) {
+        dayName = QLocale().dayName(i, QLocale::LongFormat).toLower();
         m_KeywordMap[dayName] = i + 100;
     }
-    lineEdit()->installEventFilter(this);   // handle keyword entry
+    lineEdit()->installEventFilter(this); // handle keyword entry
 
     m_TextChanged = false;
     m_HandleInvalid = false;
@@ -101,11 +99,11 @@ AnnotationDialog::DateEdit::~DateEdit()
 {
 }
 
-void AnnotationDialog::DateEdit::setDate(const QDate& newDate)
+void AnnotationDialog::DateEdit::setDate(const QDate &newDate)
 {
     QString dateString = QString::fromLatin1("");
-    if(newDate.isValid())
-        dateString = DB::ImageDate( newDate ).toString( false );
+    if (newDate.isValid())
+        dateString = DB::ImageDate(newDate).toString(false);
 
     m_TextChanged = false;
 
@@ -140,7 +138,7 @@ bool AnnotationDialog::DateEdit::isReadOnly() const
     return m_ReadOnly;
 }
 
-bool AnnotationDialog::DateEdit::validate( const QDate & )
+bool AnnotationDialog::DateEdit::validate(const QDate &)
 {
     return true;
 }
@@ -157,7 +155,7 @@ QDate AnnotationDialog::DateEdit::defaultDate() const
     return m_defaultValue;
 }
 
-void AnnotationDialog::DateEdit::setDefaultDate(const QDate& date)
+void AnnotationDialog::DateEdit::setDefaultDate(const QDate &date)
 {
     m_defaultValue = date;
 }
@@ -170,27 +168,27 @@ void AnnotationDialog::DateEdit::showPopup()
     QRect desk = QApplication::desktop()->availableGeometry(this);
 
     // ensure that the popup is fully visible even when the DateEdit is off-screen
-    QPoint popupPoint = mapToGlobal( QPoint( 0,0 ) );
-    if ( popupPoint.x() < desk.left() ) {
-        popupPoint.setX( desk.x() );
-    } else if ( popupPoint.x() + width() > desk.right()) {
-        popupPoint.setX( desk.right() - width());
+    QPoint popupPoint = mapToGlobal(QPoint(0, 0));
+    if (popupPoint.x() < desk.left()) {
+        popupPoint.setX(desk.x());
+    } else if (popupPoint.x() + width() > desk.right()) {
+        popupPoint.setX(desk.right() - width());
     }
     int dateFrameHeight = m_DateFrame->sizeHint().height();
-    if ( popupPoint.y() + height() + dateFrameHeight > desk.bottom() ) {
-        popupPoint.setY( popupPoint.y() - dateFrameHeight );
+    if (popupPoint.y() + height() + dateFrameHeight > desk.bottom()) {
+        popupPoint.setY(popupPoint.y() - dateFrameHeight);
     } else {
-        popupPoint.setY( popupPoint.y() + height() );
+        popupPoint.setY(popupPoint.y() + height());
     }
 
-    m_DateFrame->move( popupPoint );
+    m_DateFrame->move(popupPoint);
 
     QDate date;
     readDate(date, 0);
     if (date.isValid()) {
-        m_DatePicker->setDate( date );
+        m_DatePicker->setDate(date);
     } else {
-        m_DatePicker->setDate( m_defaultValue );
+        m_DatePicker->setDate(m_defaultValue);
     }
 
     m_DateFrame->show();
@@ -201,7 +199,7 @@ void AnnotationDialog::DateEdit::dateSelected(QDate newDate)
     if ((m_HandleInvalid || newDate.isValid()) && validate(newDate)) {
         setDate(newDate);
         emit dateChanged(newDate);
-        emit dateChanged( DB::ImageDate( QDateTime(newDate), QDateTime(newDate) ) );
+        emit dateChanged(DB::ImageDate(QDateTime(newDate), QDateTime(newDate)));
         m_DateFrame->hide();
     }
 }
@@ -211,26 +209,24 @@ void AnnotationDialog::DateEdit::dateEntered(QDate newDate)
     if ((m_HandleInvalid || newDate.isValid()) && validate(newDate)) {
         setDate(newDate);
         emit dateChanged(newDate);
-        emit dateChanged( DB::ImageDate( QDateTime(newDate), QDateTime(newDate) ) );
+        emit dateChanged(DB::ImageDate(QDateTime(newDate), QDateTime(newDate)));
     }
 }
 
 void AnnotationDialog::DateEdit::lineEnterPressed()
 {
-    if ( !m_TextChanged )
+    if (!m_TextChanged)
         return;
 
     QDate date;
     QDate end;
-    if (readDate(date, &end) && (m_HandleInvalid || date.isValid()) && validate(date))
-    {
+    if (readDate(date, &end) && (m_HandleInvalid || date.isValid()) && validate(date)) {
         // Update the edit. This is needed if the user has entered a
         // word rather than the actual date.
         setDate(date);
         emit(dateChanged(date));
-        emit dateChanged( DB::ImageDate( QDateTime(date), QDateTime(end) ) );
-    }
-    else {
+        emit dateChanged(DB::ImageDate(QDateTime(date), QDateTime(end)));
+    } else {
         // Invalid or unacceptable date - revert to previous value
         setDate(m_value);
         emit invalidDateEntered();
@@ -248,19 +244,16 @@ bool AnnotationDialog::DateEdit::inputIsValid() const
  * text will be interpreted as a date.
  * Returns true if the date text is blank or valid, false otherwise.
  */
-bool AnnotationDialog::DateEdit::readDate(QDate& result, QDate* end) const
+bool AnnotationDialog::DateEdit::readDate(QDate &result, QDate *end) const
 {
     QString text = currentText();
 
     if (text.isEmpty()) {
         result = QDate();
-    }
-    else if (m_KeywordMap.contains(text.toLower()))
-    {
+    } else if (m_KeywordMap.contains(text.toLower())) {
         QDate today = QDate::currentDate();
         int i = m_KeywordMap[text.toLower()];
-        if (i >= 100)
-        {
+        if (i >= 100) {
             /* A day name has been entered. Convert to offset from today.
              * This uses some math tricks to figure out the offset in days
              * to the next date the given day of the week occurs. There
@@ -277,29 +270,27 @@ bool AnnotationDialog::DateEdit::readDate(QDate& result, QDate* end) const
                 i += 7 - currentDay;
         }
         result = today.addDays(i);
-    }
-    else
-    {
-        result = DB::ImageDate::parseDate( text, m_IsStartEdit );
-        if ( end )
-            *end = DB::ImageDate::parseDate( text, false );
+    } else {
+        result = DB::ImageDate::parseDate(text, m_IsStartEdit);
+        if (end)
+            *end = DB::ImageDate::parseDate(text, false);
         return result.isValid();
     }
 
     return true;
 }
 
-void AnnotationDialog::DateEdit::keyPressEvent( QKeyEvent *event )
+void AnnotationDialog::DateEdit::keyPressEvent(QKeyEvent *event)
 {
     int step = 0;
 
-    if ( event->key() == Qt::Key_Up )
+    if (event->key() == Qt::Key_Up)
         step = 1;
-    else if ( event->key() == Qt::Key_Down )
+    else if (event->key() == Qt::Key_Down)
         step = -1;
 
-    setDate( m_value.addDays(step) );
-    QComboBox::keyPressEvent( event );
+    setDate(m_value.addDays(step));
+    QComboBox::keyPressEvent(event);
 }
 
 /* Checks for a focus out event. The display of the date is updated
@@ -310,22 +301,21 @@ bool AnnotationDialog::DateEdit::eventFilter(QObject *obj, QEvent *e)
     if (obj == lineEdit()) {
         if (e->type() == QEvent::Wheel) {
             // Up and down arrow keys step the date
-            QWheelEvent* we = dynamic_cast<QWheelEvent*>(e);
-            Q_ASSERT( we != nullptr );
+            QWheelEvent *we = dynamic_cast<QWheelEvent *>(e);
+            Q_ASSERT(we != nullptr);
 
             int step = 0;
             step = we->delta() > 0 ? 1 : -1;
             if (we->orientation() == Qt::Vertical) {
-                setDate( m_value.addDays(step) );
+                setDate(m_value.addDays(step));
             }
         }
-    }
-    else {
+    } else {
         // It's a date picker event
         switch (e->type()) {
         case QEvent::MouseButtonDblClick:
         case QEvent::MouseButtonPress: {
-            QMouseEvent *me = (QMouseEvent*)e;
+            QMouseEvent *me = (QMouseEvent *)e;
             if (!m_DateFrame->rect().contains(me->pos())) {
                 QPoint globalPos = m_DateFrame->mapToGlobal(me->pos());
                 if (QApplication::widgetAt(globalPos) == this) {
@@ -346,7 +336,7 @@ bool AnnotationDialog::DateEdit::eventFilter(QObject *obj, QEvent *e)
 
 void AnnotationDialog::DateEdit::mousePressEvent(QMouseEvent *e)
 {
-    if (e->button() == Qt::LeftButton  &&  m_DiscardNextMousePress) {
+    if (e->button() == Qt::LeftButton && m_DiscardNextMousePress) {
         m_DiscardNextMousePress = false;
         return;
     }
