@@ -17,9 +17,11 @@
 */
 
 #include "DescriptionEdit.h"
+
 #include <QKeyEvent>
 
-AnnotationDialog::DescriptionEdit::DescriptionEdit(QWidget *parent) : KTextEdit(parent)
+AnnotationDialog::DescriptionEdit::DescriptionEdit(QWidget *parent)
+    : KTextEdit(parent)
 {
 }
 
