@@ -18,8 +18,8 @@
 
 #ifndef IMAGEPREVIEW_H
 #define IMAGEPREVIEW_H
-#include "DB/ImageInfo.h"
-#include "ImageManager/ImageClientInterface.h"
+#include <DB/ImageInfo.h>
+#include <ImageManager/ImageClientInterface.h>
 
 #include <QLabel>
 #include <QTimer>
@@ -31,18 +31,19 @@ namespace AnnotationDialog
 {
 class ResizableFrame;
 
-class ImagePreview :public QLabel, public ImageManager::ImageClientInterface {
+class ImagePreview : public QLabel, public ImageManager::ImageClientInterface
+{
     Q_OBJECT
 public:
-    explicit ImagePreview( QWidget* parent );
-    int heightForWidth( int width ) const override;
+    explicit ImagePreview(QWidget *parent);
+    int heightForWidth(int width) const override;
     QSize sizeHint() const override;
     void rotate(int angle);
-    void setImage( const DB::ImageInfo& info );
-    void setImage( const QString& fileName );
+    void setImage(const DB::ImageInfo &info);
+    void setImage(const QString &fileName);
     int angle() const;
     void anticipate(DB::ImageInfo &info1);
-    void pixmapLoaded(ImageManager::ImageRequest* request, const QImage& image) override;
+    void pixmapLoaded(ImageManager::ImageRequest *request, const QImage &image) override;
     QRect areaPreviewToActual(QRect area) const;
     QRect minMaxAreaPreview() const;
     void createTaggedArea(QString category, QString tag, QRect geometry, bool showArea);
@@ -58,13 +59,13 @@ signals:
     void proposedTagSelected(QString category, QString tag);
 
 protected:
-    void resizeEvent( QResizeEvent* ) override;
+    void resizeEvent(QResizeEvent *) override;
     void mousePressEvent(QMouseEvent *event) override;
     void mouseMoveEvent(QMouseEvent *event) override;
     void mouseReleaseEvent(QMouseEvent *event) override;
     void reload();
     void setCurrentImage(const QImage &image);
-    QImage rotateAndScale( QImage, int width, int height, int angle ) const;
+    QImage rotateAndScale(QImage, int width, int height, int angle) const;
     void updateScaleFactors();
 
     QRect areaActualToPreview(QRect area) const;
@@ -72,14 +73,16 @@ protected:
     void remapAreas();
     void rotateAreas(int angle);
 
-    class PreviewImage {
+    class PreviewImage
+    {
     public:
         bool has(const DB::FileName &fileName, int angle) const;
         QImage &getImage();
         void set(const DB::FileName &fileName, const QImage &image, int angle);
         void set(const PreviewImage &other);
-        void setAngle( int angle );
+        void setAngle(int angle);
         void reset();
+
     protected:
         DB::FileName m_fileName;
         QImage m_image;
@@ -88,21 +91,23 @@ protected:
 
     struct PreloadInfo {
         PreloadInfo();
-        void set(const DB::FileName& fileName, int angle);
+        void set(const DB::FileName &fileName, int angle);
         DB::FileName m_fileName;
         int m_angle;
     };
 
-    class PreviewLoader : public ImageManager::ImageClientInterface, public PreviewImage  {
+    class PreviewLoader : public ImageManager::ImageClientInterface, public PreviewImage
+    {
     public:
-        void preloadImage( const DB::FileName& fileName, int width, int height, int angle);
+        void preloadImage(const DB::FileName &fileName, int width, int height, int angle);
         void cancelPreload();
-        void pixmapLoaded(ImageManager::ImageRequest* request, const QImage& image) override;
+        void pixmapLoaded(ImageManager::ImageRequest *request, const QImage &image) override;
     };
     PreviewLoader m_preloader;
 
 protected slots:
     void resizeFinished();
+
 private:
     DB::ImageInfo m_info;
     QString m_fileName;
@@ -131,7 +136,6 @@ private:
     bool fuzzyAreaExists(QList<QRect> &existingAreas, QRect area);
     float distance(QPoint point1, QPoint point2);
 };
-
 }
 
 #endif /* IMAGEPREVIEW_H */
