@@ -1,4 +1,4 @@
-/* Copyright (C) 2003-2018 Jesper K. Pedersen <blackie@kde.org>
+/* Copyright (C) 2003-2019 Jesper K. Pedersen <blackie@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -20,32 +20,35 @@
 #define IMAGEPREVIEWWIDGET_H
 
 // Qt includes
-#include <QWidget>
 #include <QList>
+#include <QWidget>
 
 // Local includes
-#include "DB/ImageInfo.h"
 #include "ImagePreview.h"
 
+#include <DB/ImageInfo.h>
+
 class QCheckBox;
 class QPushButton;
 class QComboBox;
+class KActionCollection;
 
 namespace AnnotationDialog
 {
 
-class ImagePreviewWidget :public QWidget{
+class ImagePreviewWidget : public QWidget
+{
     Q_OBJECT
 public:
-    ImagePreviewWidget();
-    void rotate(int angle) ;
-    void setImage( const DB::ImageInfo& info );
-    void setImage( const QString& fileName );
-    void setImage( const int index );
-    void configure( QList<DB::ImageInfo>* imageList, bool singleEdit );
+    ImagePreviewWidget(KActionCollection *actions);
+    void rotate(int angle);
+    void setImage(const DB::ImageInfo &info);
+    void setImage(const QString &fileName);
+    void setImage(const int index);
+    void configure(QList<DB::ImageInfo> *imageList, bool singleEdit);
     int angle() const;
     void anticipate(DB::ImageInfo &info1);
-    const QString& lastImage();
+    const QString &lastImage();
     ImagePreview *preview() const;
     bool showAreas() const;
     void canCreateAreas(bool state);
@@ -65,14 +68,17 @@ public slots:
     void slotShowAreas(bool show);
 
 signals:
-    void imageDeleted( const DB::ImageInfo& deletedImage );
-    void imageRotated( int angle);
-    void imageChanged( const DB::ImageInfo& newImage );
-    void indexChanged( int newIndex );
+    void imageDeleted(const DB::ImageInfo &deletedImage);
+    void imageRotated(int angle);
+    void imageChanged(const DB::ImageInfo &newImage);
+    void indexChanged(int newIndex);
     void copyPrevClicked();
     void areaVisibilityChanged(bool visible);
     void togglePreview();
 
+protected:
+    void showEvent(QShowEvent *) override;
+
 private: // Functions
     /**
      * Update labels and tooltip texts when canCreateAreas() changes.
@@ -81,24 +87,24 @@ private: // Functions
     void toggleFullscreenPreview();
 
 private: // Variables
-    ImagePreview* m_preview;
-    QPushButton* m_prevBut;
-    QPushButton* m_nextBut;
+    ImagePreview *m_preview;
+    QPushButton *m_prevBut;
+    QPushButton *m_nextBut;
     QPushButton *m_toggleFullscreenPreview;
-    QPushButton* m_rotateLeft;
-    QPushButton* m_rotateRight;
-    QPushButton* m_delBut;
-    QPushButton* m_copyPreviousBut;
+    QPushButton *m_rotateLeft;
+    QPushButton *m_rotateRight;
+    QPushButton *m_delBut;
+    QPushButton *m_copyPreviousBut;
     QPushButton *m_facedetectBut;
     QPushButton *m_toggleAreasBut;
-    QList<DB::ImageInfo>* m_imageList;
+    QList<DB::ImageInfo> *m_imageList;
     int m_current;
     bool m_singleEdit;
-    QLabel* m_defaultAreaCategoryLabel;
-    QComboBox* m_defaultAreaCategory;
-    QWidget* m_controlWidget;
+    QLabel *m_defaultAreaCategoryLabel;
+    QComboBox *m_defaultAreaCategory;
+    QWidget *m_controlWidget;
+    KActionCollection *m_actions;
 };
-
 }
 
 #endif /* IMAGEPREVIEWWIDGET_H */
