@@ -1,4 +1,4 @@
-/* Copyright 2012 Jesper K. Pedersen <blackie@kde.org>
+/* Copyright (C) 2012-2019 The KPhotoAlbum Development Team
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -18,29 +18,32 @@
 */
 
 #include "JobModel.h"
-#include "JobManager.h"
-#include "JobInfo.h"
-#include <KLocalizedString>
+
 #include "CompletedJobInfo.h"
-#include <QPixmap>
-#include <QPainter>
+#include "JobInfo.h"
+#include "JobManager.h"
+
 #include <KLed>
+#include <KLocalizedString>
+#include <QPainter>
+#include <QPixmap>
 #include <QTime>
 #include <QTimer>
 
-namespace BackgroundTaskManager {
-
-JobModel::JobModel(QObject *parent) :
-    QAbstractTableModel(parent)
-  ,blinkStateOn(true)
+namespace BackgroundTaskManager
 {
-    connect( JobManager::instance(), SIGNAL(jobStarted(JobInterface*)), this, SLOT(jobStarted(JobInterface*)));
-    connect( JobManager::instance(), SIGNAL(jobEnded(JobInterface*)), this, SLOT(jobEnded(JobInterface*)));
+
+JobModel::JobModel(QObject *parent)
+    : QAbstractTableModel(parent)
+    , blinkStateOn(true)
+{
+    connect(JobManager::instance(), SIGNAL(jobStarted(JobInterface *)), this, SLOT(jobStarted(JobInterface *)));
+    connect(JobManager::instance(), SIGNAL(jobEnded(JobInterface *)), this, SLOT(jobEnded(JobInterface *)));
 
     // Make the current task blink
-    QTimer* timer = new QTimer(this);
+    QTimer *timer = new QTimer(this);
     timer->start(500);
-    connect(timer, SIGNAL(timeout()), this, SLOT(heartbeat()));
+    connect(timer, &QTimer::timeout, this, &JobModel::heartbeat);
 }
 
 JobModel::~JobModel()
@@ -48,9 +51,9 @@ JobModel::~JobModel()
     qDeleteAll(m_previousJobs);
 }
 
-int JobModel::rowCount(const QModelIndex& index) const
+int JobModel::rowCount(const QModelIndex &index) const
 {
-    if ( index.isValid())
+    if (index.isValid())
         return 0;
     else
         return m_previousJobs.count() + JobManager::instance()->activeJobCount() + JobManager::instance()->futureJobCount();
@@ -63,28 +66,32 @@ int JobModel::columnCount(const QModelIndex &) const
 
 QVariant JobModel::data(const QModelIndex &index, int role) const
 {
-    if ( !index.isValid() )
+    if (!index.isValid())
         return QVariant();
 
     const int row = index.row();
     const int col = index.column();
 
-    JobInfo* current = info(row);
-    if ( !current )
+    JobInfo *current = info(row);
+    if (!current)
         return QVariant();
 
-    if ( role == Qt::DisplayRole ) {
+    if (role == Qt::DisplayRole) {
         switch (col) {
-        case IDCol: return current->jobIndex();
-        case TitleCol:   return current->title();
-        case DetailsCol: return current->details();
-        case ElapsedCol: return current->elapsed();
-        default: return QVariant();
+        case IDCol:
+            return current->jobIndex();
+        case TitleCol:
+            return current->title();
+        case DetailsCol:
+            return current->details();
+        case ElapsedCol:
+            return current->elapsed();
+        default:
+            return QVariant();
         }
-    }
-    else if ( role == Qt::DecorationRole && col == TitleCol )
+    } else if (role == Qt::DecorationRole && col == TitleCol)
         return statusImage(current->state);
-    else if ( role == Qt::TextAlignmentRole )
+    else if (role == Qt::TextAlignmentRole)
         return index.column() == IDCol ? Qt::AlignRight : Qt::AlignLeft;
 
     return QVariant();
@@ -92,14 +99,19 @@ QVariant JobModel::data(const QModelIndex &index, int role) const
 
 QVariant JobModel::headerData(int section, Qt::Orientation orientation, int role) const
 {
-    if ( orientation != Qt::Horizontal || role != Qt::DisplayRole)
+    if (orientation != Qt::Horizontal || role != Qt::DisplayRole)
         return QVariant();
     switch (section) {
-        case IDCol: return i18nc("@title:column Background job id","ID");
-        case TitleCol:   return i18nc("@title:column Background job title","Title");
-        case DetailsCol: return i18nc("@title:column Additional information on background job","Details");
-        case ElapsedCol: return i18nc("@title:column Elapsed time","Elapsed");
-        default: return QVariant();
+    case IDCol:
+        return i18nc("@title:column Background job id", "ID");
+    case TitleCol:
+        return i18nc("@title:column Background job title", "Title");
+    case DetailsCol:
+        return i18nc("@title:column Additional information on background job", "Details");
+    case ElapsedCol:
+        return i18nc("@title:column Elapsed time", "Elapsed");
+    default:
+        return QVariant();
     }
 }
 
@@ -117,13 +129,13 @@ void JobModel::reset()
 
 void JobModel::jobEnded(JobInterface *job)
 {
-    m_previousJobs.append( new CompletedJobInfo(job) );
+    m_previousJobs.append(new CompletedJobInfo(job));
     reset();
 }
 
 void JobModel::jobStarted(JobInterface *job)
 {
-    connect( job, SIGNAL(changed()), this, SLOT(reset()));
+    connect(job, SIGNAL(changed()), this, SLOT(reset()));
     reset();
 }
 
@@ -135,26 +147,26 @@ void JobModel::heartbeat()
     endResetModel();
 }
 
-JobInfo* JobModel::info(int row) const
+JobInfo *JobModel::info(int row) const
 {
-    if ( row < m_previousJobs.count() )
-        return  m_previousJobs[row];
+    if (row < m_previousJobs.count())
+        return m_previousJobs[row];
 
     row -= m_previousJobs.count();
-    if ( row  < JobManager::instance()->activeJobCount() )
+    if (row < JobManager::instance()->activeJobCount())
         return JobManager::instance()->activeJob(row);
 
     row -= JobManager::instance()->activeJobCount();
-    Q_ASSERT( row < JobManager::instance()->futureJobCount() );
+    Q_ASSERT(row < JobManager::instance()->futureJobCount());
     return JobManager::instance()->futureJob(row);
 }
 
 QPixmap JobModel::statusImage(JobInfo::State state) const
 {
     QColor color;
-    if ( state == JobInfo::Running )
-        color = blinkStateOn ?  Qt::green : Qt::gray;
-    else if ( state == JobInfo::Completed )
+    if (state == JobInfo::Running)
+        color = blinkStateOn ? Qt::green : Qt::gray;
+    else if (state == JobInfo::Completed)
         color = Qt::red;
     else
         color = QColor(Qt::yellow).darker();
