@@ -1,4 +1,4 @@
-/* Copyright 2012 Jesper K. Pedersen <blackie@kde.org>
+/* Copyright (C) 2012-2019 The KPhotoAlbum Development Team
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -18,36 +18,41 @@
 */
 
 #include "StatusIndicator.h"
-#include <QTimer>
-#include <QApplication>
+
 #include "JobManager.h"
 #include "JobViewer.h"
-#include <QToolTip>
+
 #include <KLocalizedString>
+#include <QApplication>
 #include <QHelpEvent>
+#include <QTimer>
+#include <QToolTip>
 
-namespace BackgroundTaskManager {
-
-StatusIndicator::StatusIndicator( QWidget* parent )
-    : KLed( Qt::green, parent ), m_timer( new QTimer(this) ), m_jobViewer(nullptr)
+namespace BackgroundTaskManager
 {
-    connect( m_timer, SIGNAL(timeout()), this, SLOT(flicker()));
+
+StatusIndicator::StatusIndicator(QWidget *parent)
+    : KLed(Qt::green, parent)
+    , m_timer(new QTimer(this))
+    , m_jobViewer(nullptr)
+{
+    connect(m_timer, &QTimer::timeout, this, &StatusIndicator::flicker);
     setCursor(Qt::PointingHandCursor);
-    connect( JobManager::instance(), SIGNAL(jobStarted(JobInterface*)), this, SLOT(maybeStartFlicker()));
+    connect(JobManager::instance(), SIGNAL(jobStarted(JobInterface *)), this, SLOT(maybeStartFlicker()));
 }
 
 bool StatusIndicator::event(QEvent *event)
 {
-    if ( event->type() == QEvent::ToolTip ) {
-        showToolTip(dynamic_cast<QHelpEvent*>(event));
+    if (event->type() == QEvent::ToolTip) {
+        showToolTip(dynamic_cast<QHelpEvent *>(event));
         return true;
     }
     return KLed::event(event);
 }
 
-void StatusIndicator::mouseReleaseEvent(QMouseEvent*)
+void StatusIndicator::mouseReleaseEvent(QMouseEvent *)
 {
-    if ( !m_jobViewer )
+    if (!m_jobViewer)
         m_jobViewer = new JobViewer;
 
     m_jobViewer->setVisible(!m_jobViewer->isVisible());
@@ -57,21 +62,20 @@ void StatusIndicator::flicker()
 {
     QColor newColor;
 
-    if ( !JobManager::instance()->hasActiveJobs() ) {
+    if (!JobManager::instance()->hasActiveJobs()) {
         m_timer->stop();
         newColor = Qt::gray;
-    }
-    else if ( JobManager::instance()->isPaused() && !JobManager::instance()->hasActiveJobs() )
+    } else if (JobManager::instance()->isPaused() && !JobManager::instance()->hasActiveJobs())
         newColor = QColor(Qt::yellow).lighter();
     else
-         newColor = (color() == Qt::gray ? currentColor() : Qt::gray);
+        newColor = (color() == Qt::gray ? currentColor() : Qt::gray);
 
-    setColor( newColor );
+    setColor(newColor);
 }
 
 void StatusIndicator::maybeStartFlicker()
 {
-    if ( !m_timer->isActive())
+    if (!m_timer->isActive())
         m_timer->start(500);
 }
 
@@ -80,22 +84,21 @@ QColor StatusIndicator::currentColor() const
     return JobManager::instance()->isPaused() ? Qt::yellow : Qt::green;
 }
 
-void StatusIndicator::showToolTip(QHelpEvent* event)
+void StatusIndicator::showToolTip(QHelpEvent *event)
 {
     const int activeCount = JobManager::instance()->activeJobCount();
-    const int pendingCount  = JobManager::instance()->futureJobCount();
+    const int pendingCount = JobManager::instance()->futureJobCount();
 
-    const QString text =
-            i18n("<p>Active jobs: %1<br/>"
-                 "Pending jobs: %2"
-                 "<hr/><br/>"
-                 "Color codes:"
-                 "<ul><li><b>blinking green</b>: Active background jobs</li>"
-                 "<li><b>gray</b>: No active jobs</li>"
-                 "<li><b>solid yellow</b>: Job queue is paused</li>"
-                 "<li><b>blinking yellow</b>: Job queue is paused for background jobs, but is executing a foreground job "
-                 "(like extracting a thumbnail for a video file, which is currently shown in the thumbnail viewer)</li></ul></p>"
-                 ,activeCount,pendingCount);
+    const QString text = i18n("<p>Active jobs: %1<br/>"
+                              "Pending jobs: %2"
+                              "<hr/><br/>"
+                              "Color codes:"
+                              "<ul><li><b>blinking green</b>: Active background jobs</li>"
+                              "<li><b>gray</b>: No active jobs</li>"
+                              "<li><b>solid yellow</b>: Job queue is paused</li>"
+                              "<li><b>blinking yellow</b>: Job queue is paused for background jobs, but is executing a foreground job "
+                              "(like extracting a thumbnail for a video file, which is currently shown in the thumbnail viewer)</li></ul></p>",
+                              activeCount, pendingCount);
     QToolTip::showText(event->globalPos(), text);
 }
 
