@@ -17,42 +17,47 @@
 */
 
 #include "CategoryPage.h"
-#include "TreeCategoryModel.h"
-#include "FlatCategoryModel.h"
-#include <KLocalizedString>
-#include "OverviewPage.h"
-#include "BrowserWidget.h"
-#include "enums.h"
-#include <DB/ImageDB.h>
-#include "ImageViewPage.h"
 
-Browser::CategoryPage::CategoryPage( const DB::CategoryPtr& category, const DB::ImageSearchInfo& info, BrowserWidget* browser )
-    : BrowserPage( info, browser ), m_category( category ), m_model( nullptr )
+#include "BrowserWidget.h"
+#include "FlatCategoryModel.h"
+#include "ImageViewPage.h"
+#include "OverviewPage.h"
+#include "TreeCategoryModel.h"
+#include "enums.h"
+
+#include <DB/ImageDB.h>
+
+#include <KLocalizedString>
+
+Browser::CategoryPage::CategoryPage(const DB::CategoryPtr &category, const DB::ImageSearchInfo &info, BrowserWidget *browser)
+    : BrowserPage(info, browser)
+    , m_category(category)
+    , m_model(nullptr)
 {
 }
 
 void Browser::CategoryPage::activate()
 {
     delete m_model;
-    if ( m_category->viewType() == DB::Category::TreeView || m_category->viewType() == DB::Category::ThumbedTreeView )
-        m_model = new TreeCategoryModel( m_category, searchInfo() );
+    if (m_category->viewType() == DB::Category::TreeView || m_category->viewType() == DB::Category::ThumbedTreeView)
+        m_model = new TreeCategoryModel(m_category, searchInfo());
     else
-        m_model = new FlatCategoryModel( m_category, searchInfo() );
+        m_model = new FlatCategoryModel(m_category, searchInfo());
 
-    browser()->setModel( m_model );
+    browser()->setModel(m_model);
 }
 
-Browser::BrowserPage* Browser::CategoryPage::activateChild( const QModelIndex& index )
+Browser::BrowserPage *Browser::CategoryPage::activateChild(const QModelIndex &index)
 {
-    const QString name = m_model->data( index, ItemNameRole ).value<QString>();
+    const QString name = m_model->data(index, ItemNameRole).value<QString>();
     DB::ImageSearchInfo info = searchInfo();
 
-    info.addAnd( m_category->name(), name );
+    info.addAnd(m_category->name(), name);
     if (DB::ImageDB::instance()->search(info).size() <= Settings::SettingsData::instance()->autoShowThumbnailView()) {
-        browser()->addAction( new Browser::OverviewPage( Breadcrumb(name), info, browser() ) );
-        return new ImageViewPage( info, browser() );
+        browser()->addAction(new Browser::OverviewPage(Breadcrumb(name), info, browser()));
+        return new ImageViewPage(info, browser());
     } else
-        return new Browser::OverviewPage( Breadcrumb(name), info, browser() );
+        return new Browser::OverviewPage(Breadcrumb(name), info, browser());
 }
 
 DB::CategoryPtr Browser::CategoryPage::category() const
