@@ -21,42 +21,44 @@
 
 // Local includes
 #include "TreeCategoryModel.h"
-#include "DB/ImageDB.h"
-#include "DB/CategoryItem.h"
-#include "DB/Category.h"
-#include "MainWindow/DirtyIndicator.h"
 
-struct Browser::TreeCategoryModel::Data
-{
-    Data(const QString& name)
-        : name(name), parent(nullptr)
+#include <DB/Category.h>
+#include <DB/CategoryItem.h>
+#include <DB/ImageDB.h>
+#include <MainWindow/DirtyIndicator.h>
+
+struct Browser::TreeCategoryModel::Data {
+    Data(const QString &name)
+        : name(name)
+        , parent(nullptr)
     {
     }
 
-    ~Data() {
+    ~Data()
+    {
         qDeleteAll(children);
     }
 
-    void addChild(Data* child)
+    void addChild(Data *child)
     {
         child->parent = this;
         children.append(child);
     }
 
     QString name;
-    QList<Data*> children;
-    Data* parent;
+    QList<Data *> children;
+    Data *parent;
 };
 
-Browser::TreeCategoryModel::TreeCategoryModel(const DB::CategoryPtr& category,
-                                              const DB::ImageSearchInfo& info)
+Browser::TreeCategoryModel::TreeCategoryModel(const DB::CategoryPtr &category,
+                                              const DB::ImageSearchInfo &info)
     : AbstractCategoryModel(category, info)
 {
     m_data = new Data(QString());
     createData(m_category->itemsCategories().data(), 0);
 
     if (hasNoneEntry()) {
-        Data* data = new Data(DB::ImageDB::NONE());
+        Data *data = new Data(DB::ImageDB::NONE());
         data->parent = m_data;
         m_data->children.prepend(data);
     }
@@ -64,22 +66,22 @@ Browser::TreeCategoryModel::TreeCategoryModel(const DB::CategoryPtr& category,
     m_memberMap = DB::ImageDB::instance()->memberMap();
 }
 
-int Browser::TreeCategoryModel::rowCount(const QModelIndex& index) const
+int Browser::TreeCategoryModel::rowCount(const QModelIndex &index) const
 {
     return indexToData(index)->children.count();
 }
 
-int Browser::TreeCategoryModel::columnCount(const QModelIndex&) const
+int Browser::TreeCategoryModel::columnCount(const QModelIndex &) const
 {
     return 5;
 }
 
-QModelIndex Browser::TreeCategoryModel::index(int row, int column, const QModelIndex& parent) const
+QModelIndex Browser::TreeCategoryModel::index(int row, int column, const QModelIndex &parent) const
 {
-    const Data* data = indexToData(parent);
-    QList<Data*> children = data->children;
+    const Data *data = indexToData(parent);
+    QList<Data *> children = data->children;
     int size = children.count();
-    if ( row >= size || row < 0 || column >= columnCount(parent) || column < 0) {
+    if (row >= size || row < 0 || column >= columnCount(parent) || column < 0) {
         // Invalid index
         return QModelIndex();
     } else {
@@ -87,19 +89,19 @@ QModelIndex Browser::TreeCategoryModel::index(int row, int column, const QModelI
     }
 }
 
-QModelIndex Browser::TreeCategoryModel::parent(const QModelIndex& index) const
+QModelIndex Browser::TreeCategoryModel::parent(const QModelIndex &index) const
 {
-    Data* me = indexToData(index);
+    Data *me = indexToData(index);
     if (me == m_data) {
         return QModelIndex();
     }
 
-    Data* parent = me->parent;
+    Data *parent = me->parent;
     if (parent == m_data) {
         return QModelIndex();
     }
 
-    Data* grandParent = parent->parent;
+    Data *grandParent = parent->parent;
 
     return createIndex(grandParent->children.indexOf(parent), 0, parent);
 }
@@ -109,17 +111,17 @@ Browser::TreeCategoryModel::~TreeCategoryModel()
     delete m_data;
 }
 
-bool Browser::TreeCategoryModel::createData(DB::CategoryItem* parentCategoryItem, Data* parent)
+bool Browser::TreeCategoryModel::createData(DB::CategoryItem *parentCategoryItem, Data *parent)
 {
     const QString name = parentCategoryItem->mp_name;
     const int imageCount = m_images.contains(name) ? m_images[name].count : 0;
     const int videoCount = m_videos.contains(name) ? m_videos[name].count : 0;
 
-    Data* myData = new Data(name);
+    Data *myData = new Data(name);
     bool anyItems = imageCount != 0 || videoCount != 0;
 
-    for(QList<DB::CategoryItem*>::ConstIterator subCategoryIt = parentCategoryItem->mp_subcategories.constBegin();
-        subCategoryIt != parentCategoryItem->mp_subcategories.constEnd(); ++subCategoryIt) {
+    for (QList<DB::CategoryItem *>::ConstIterator subCategoryIt = parentCategoryItem->mp_subcategories.constBegin();
+         subCategoryIt != parentCategoryItem->mp_subcategories.constEnd(); ++subCategoryIt) {
         anyItems = createData(*subCategoryIt, myData) || anyItems;
     }
 
@@ -136,18 +138,18 @@ bool Browser::TreeCategoryModel::createData(DB::CategoryItem* parentCategoryItem
     return anyItems;
 }
 
-Browser::TreeCategoryModel::Data* Browser::TreeCategoryModel::indexToData(const QModelIndex& index) const
+Browser::TreeCategoryModel::Data *Browser::TreeCategoryModel::indexToData(const QModelIndex &index) const
 {
-    if (! index.isValid()) {
+    if (!index.isValid()) {
         return m_data;
     } else {
-        return static_cast<Browser::TreeCategoryModel::Data*>(index.internalPointer());
+        return static_cast<Browser::TreeCategoryModel::Data *>(index.internalPointer());
     }
 }
 
-QString Browser::TreeCategoryModel::indexToName(const QModelIndex& index) const
+QString Browser::TreeCategoryModel::indexToName(const QModelIndex &index) const
 {
-    const Browser::TreeCategoryModel::Data* data = indexToData(index);
+    const Browser::TreeCategoryModel::Data *data = indexToData(index);
     return data->name;
 }
 
@@ -156,11 +158,11 @@ Qt::DropActions Browser::TreeCategoryModel::supportedDropActions() const
     return Qt::CopyAction | Qt::MoveAction;
 }
 
-Qt::ItemFlags Browser::TreeCategoryModel::flags(const QModelIndex& index) const
+Qt::ItemFlags Browser::TreeCategoryModel::flags(const QModelIndex &index) const
 {
     Qt::ItemFlags defaultFlags = QAbstractItemModel::flags(index);
 
-    if ( m_category->isSpecialCategory() || indexToName(index) == QString::fromUtf8("**NONE**")) {
+    if (m_category->isSpecialCategory() || indexToName(index) == QString::fromUtf8("**NONE**")) {
         return defaultFlags;
     }
 
@@ -178,15 +180,15 @@ QStringList Browser::TreeCategoryModel::mimeTypes() const
     return QStringList() << QString::fromUtf8("x-kphotoalbum/x-browser-tag-drag");
 }
 
-QMimeData* Browser::TreeCategoryModel::mimeData(const QModelIndexList& indexes) const
+QMimeData *Browser::TreeCategoryModel::mimeData(const QModelIndexList &indexes) const
 {
-    QMimeData* mimeData = new QMimeData();
+    QMimeData *mimeData = new QMimeData();
     QByteArray encodedData;
     QDataStream stream(&encodedData, QIODevice::WriteOnly);
 
     // only use the first index, even if more than one are selected:
     stream << indexToName(indexes[0]);
-    if (! indexes[0].parent().isValid()) {
+    if (!indexes[0].parent().isValid()) {
         stream << QString();
     } else {
         stream << indexToName(indexes[0].parent());
@@ -196,7 +198,7 @@ QMimeData* Browser::TreeCategoryModel::mimeData(const QModelIndexList& indexes)
     return mimeData;
 }
 
-Browser::TreeCategoryModel::tagData Browser::TreeCategoryModel::getDroppedTagData(QByteArray& encodedData)
+Browser::TreeCategoryModel::tagData Browser::TreeCategoryModel::getDroppedTagData(QByteArray &encodedData)
 {
     QDataStream stream(&encodedData, QIODevice::ReadOnly);
     Browser::TreeCategoryModel::tagData droppedTagData;
@@ -205,8 +207,8 @@ Browser::TreeCategoryModel::tagData Browser::TreeCategoryModel::getDroppedTagDat
     return droppedTagData;
 }
 
-bool Browser::TreeCategoryModel::dropMimeData(const QMimeData* data, Qt::DropAction action,
-                                              int, int, const QModelIndex& parent)
+bool Browser::TreeCategoryModel::dropMimeData(const QMimeData *data, Qt::DropAction action,
+                                              int, int, const QModelIndex &parent)
 {
     if (action == Qt::IgnoreAction) {
         return true;
@@ -229,13 +231,12 @@ bool Browser::TreeCategoryModel::dropMimeData(const QMimeData* data, Qt::DropAct
         // Check if the tag is dropped onto a copy of itself
         const DB::CategoryItemPtr categoryInfo = m_category->itemsCategories();
         if (thisCategory == droppedTagData.tagName
-                || categoryInfo->isDescendentOf(thisCategory, droppedTagData.tagName) )
-        {
+            || categoryInfo->isDescendentOf(thisCategory, droppedTagData.tagName)) {
             return true;
         }
 
         // Add the tag to a group, create it if we don't have it yet
-        if (! m_memberMap.groups(m_category->name()).contains(thisCategory)) {
+        if (!m_memberMap.groups(m_category->name()).contains(thisCategory)) {
             m_memberMap.addGroup(m_category->name(), thisCategory);
             DB::ImageDB::instance()->memberMap() = m_memberMap;
         }
