@@ -17,25 +17,26 @@
 */
 #ifndef CATEGORYLISTVIEW_DragableTreeWidget_H
 #define CATEGORYLISTVIEW_DragableTreeWidget_H
+#include <DB/CategoryPtr.h>
+
 #include <QTreeWidget>
-#include "DB/CategoryPtr.h"
 
 namespace CategoryListView
 {
-class DragableTreeWidget :public QTreeWidget
+class DragableTreeWidget : public QTreeWidget
 {
     Q_OBJECT
 
 public:
-    DragableTreeWidget( const DB::CategoryPtr& category, QWidget* parent );
+    DragableTreeWidget(const DB::CategoryPtr &category, QWidget *parent);
     DB::CategoryPtr category() const;
     void emitItemsChanged();
 
 protected:
-    QMimeData* mimeData( const QList<QTreeWidgetItem*> items ) const override;
+    QMimeData *mimeData(const QList<QTreeWidgetItem *> items) const override;
     QStringList mimeTypes() const override;
-    bool dropMimeData ( QTreeWidgetItem* parent, int index, const QMimeData* data, Qt::DropAction action ) override;
-    void dragMoveEvent(QDragMoveEvent* event) override;
+    bool dropMimeData(QTreeWidgetItem *parent, int index, const QMimeData *data, Qt::DropAction action) override;
+    void dragMoveEvent(QDragMoveEvent *event) override;
 
 signals:
     void itemsChanged();
