@@ -20,9 +20,11 @@
 #ifndef FILENAME_H
 #define FILENAME_H
 
-#include <QString>
-#include <QSet>
 #include "ImageInfoPtr.h"
+
+#include <QSet>
+#include <QString>
+#include <QUrl>
 #include <QtCore/qmetatype.h>
 
 namespace DB
@@ -32,17 +34,22 @@ class FileName
 {
 public:
     FileName();
-    static FileName fromAbsolutePath( const QString& fileName );
-    static FileName fromRelativePath( const QString& fileName );
+    static FileName fromAbsolutePath(const QString &fileName);
+    static FileName fromRelativePath(const QString &fileName);
     QString absolute() const;
     QString relative() const;
     bool isNull() const;
-    bool operator==( const FileName& other ) const;
-    bool operator!=( const FileName& other ) const;
-    bool operator<( const FileName& other ) const;
+    bool operator==(const FileName &other) const;
+    bool operator!=(const FileName &other) const;
+    bool operator<(const FileName &other) const;
     bool exists() const;
     ImageInfoPtr info() const;
 
+    /**
+     * @brief Conversion to absolute local file url.
+     */
+    explicit operator QUrl() const;
+
 private:
     // During previous profilation it showed that converting between absolute and relative took quite some time,
     // so to avoid that, I store both.
@@ -51,12 +58,11 @@ private:
     bool m_isNull;
 };
 
-uint qHash( const DB::FileName& fileName );
+uint qHash(const DB::FileName &fileName);
 typedef QSet<DB::FileName> FileNameSet;
 }
 
 Q_DECLARE_METATYPE(DB::FileName)
 
-
 #endif // FILENAME_H
 // vi:expandtab:tabstop=4 shiftwidth=4:
