@@ -23,6 +23,8 @@
 
 Q_DECLARE_LOGGING_CATEGORY(DBLog)
 Q_DECLARE_LOGGING_CATEGORY(DBCategoryMatcherLog)
+Q_DECLARE_LOGGING_CATEGORY(DBImageScoutLog)
+Q_DECLARE_LOGGING_CATEGORY(FastDirLog)
 
 #endif /* DB_LOGGING_H */
 
