@@ -18,15 +18,16 @@
 
 #ifndef MD5MAP_H
 #define MD5MAP_H
-#include <qstring.h>
-#include <qhash.h>
+#include "FileName.h"
 #include "MD5.h"
-#include <DB/FileName.h>
+
+#include <qhash.h>
+#include <qstring.h>
 
 namespace DB
 {
-    typedef QHash<MD5, DB::FileName> MD5FileMap;
-    typedef QHash<DB::FileName, MD5> FileMD5Map;
+typedef QHash<MD5, DB::FileName> MD5FileMap;
+typedef QHash<DB::FileName, MD5> FileMD5Map;
 
 /**
    This class may be overridden by a which wants to store md5 information
@@ -36,13 +37,13 @@ class MD5Map
 {
 public:
     virtual ~MD5Map() {}
-    virtual void insert( const MD5& md5sum, const DB::FileName& fileName );
-    virtual DB::FileName lookup( const MD5& md5sum ) const;
-    virtual MD5 lookupFile( const DB::FileName& fileName ) const;
-    virtual bool contains( const MD5& md5sum ) const;
-    virtual bool containsFile( const DB::FileName& fileName ) const;
+    virtual void insert(const MD5 &md5sum, const DB::FileName &fileName);
+    virtual DB::FileName lookup(const MD5 &md5sum) const;
+    virtual MD5 lookupFile(const DB::FileName &fileName) const;
+    virtual bool contains(const MD5 &md5sum) const;
+    virtual bool containsFile(const DB::FileName &fileName) const;
     virtual void clear();
-    virtual DB::FileNameSet diff( const MD5Map& other ) const;
+    virtual DB::FileNameSet diff(const MD5Map &other) const;
 
 private:
     MD5FileMap m_map;
@@ -51,7 +52,6 @@ private:
 
 }
 
-
 #endif /* MD5MAP_H */
 
 // vi:expandtab:tabstop=4 shiftwidth=4:
