@@ -17,37 +17,41 @@
 */
 
 #include "MemberMap.h"
+
+#include "Category.h"
 #include "Logging.h"
-#include "DB/Category.h"
 
 using namespace DB;
 
-MemberMap::MemberMap() :QObject(nullptr), m_dirty( true ), m_loading( false )
+MemberMap::MemberMap()
+    : QObject(nullptr)
+    , m_dirty(true)
+    , m_loading(false)
 {
 }
 
 /**
    returns the groups directly available from category (non closure that is)
 */
-QStringList MemberMap::groups( const QString& category ) const
+QStringList MemberMap::groups(const QString &category) const
 {
-    return QStringList( m_members[ category ].keys() );
+    return QStringList(m_members[category].keys());
 }
 
-bool MemberMap::contains( const QString& category, const QString& item) const
+bool MemberMap::contains(const QString &category, const QString &item) const
 {
     return m_flatMembers[category].contains(item);
 }
 
-void MemberMap::markDirty( const QString& category )
+void MemberMap::markDirty(const QString &category)
 {
-    if ( m_loading )
-        regenerateFlatList( category );
+    if (m_loading)
+        regenerateFlatList(category);
     else
         emit dirty();
 }
 
-void MemberMap::deleteGroup( const QString& category, const QString& name )
+void MemberMap::deleteGroup(const QString &category, const QString &name)
 {
     m_members[category].remove(name);
     m_dirty = true;
@@ -57,18 +61,17 @@ void MemberMap::deleteGroup( const QString& category, const QString& name )
 /**
    return all the members of memberGroup
 */
-QStringList MemberMap::members( const QString& category, const QString& memberGroup, bool closure ) const
+QStringList MemberMap::members(const QString &category, const QString &memberGroup, bool closure) const
 {
-    if ( closure ) {
-        if ( m_dirty )
+    if (closure) {
+        if (m_dirty)
             calculate();
         return m_closureMembers[category][memberGroup].toList();
-    }
-    else
+    } else
         return m_members[category][memberGroup].toList();
 }
 
-void MemberMap::setMembers( const QString& category, const QString& memberGroup, const QStringList& members )
+void MemberMap::setMembers(const QString &category, const QString &memberGroup, const QStringList &members)
 {
     StringSet allowedMembers = members.toSet();
 
@@ -78,7 +81,7 @@ void MemberMap::setMembers( const QString& category, const QString& memberGroup,
 
     m_members[category][memberGroup] = allowedMembers;
     m_dirty = true;
-    markDirty( category );
+    markDirty(category);
 }
 
 bool MemberMap::isEmpty() const
@@ -89,19 +92,18 @@ bool MemberMap::isEmpty() const
 /**
    returns true if item is a group for category.
 */
-bool MemberMap::isGroup( const QString& category, const QString& item ) const
+bool MemberMap::isGroup(const QString &category, const QString &item) const
 {
     return m_members[category].find(item) != m_members[category].end();
 }
 
-
 /**
    return a map from groupName to list of items for category
    example: { USA |-> [Chicago, Grand Canyon, Santa Clara], Denmark |-> [Esbjerg, Odense] }
 */
-QMap<QString,StringSet> MemberMap::groupMap( const QString& category ) const
+QMap<QString, StringSet> MemberMap::groupMap(const QString &category) const
 {
-    if ( m_dirty )
+    if (m_dirty)
         calculate();
 
     return m_closureMembers[category];
@@ -113,17 +115,16 @@ QMap<QString,StringSet> MemberMap::groupMap( const QString& category ) const
    Califonia consists of members San Fransisco and Los Angeless.
    This function then maps USA to include Califonia, San Fransisco and Los Angeless.
 */
-QStringList MemberMap::calculateClosure( QMap<QString,StringSet>& resultSoFar, const QString& category, const QString& group ) const
+QStringList MemberMap::calculateClosure(QMap<QString, StringSet> &resultSoFar, const QString &category, const QString &group) const
 {
     resultSoFar[group] = StringSet(); // Prevent against cykles.
     StringSet members = m_members[category][group];
     StringSet result = members;
-    for( StringSet::const_iterator it = members.begin(); it != members.end(); ++it ) {
-        if ( resultSoFar.contains( *it ) ) {
+    for (StringSet::const_iterator it = members.begin(); it != members.end(); ++it) {
+        if (resultSoFar.contains(*it)) {
             result += resultSoFar[*it];
-        }
-        else if ( isGroup(category, *it ) ) {
-            result += calculateClosure( resultSoFar, category, *it ).toSet();
+        } else if (isGroup(category, *it)) {
+            result += calculateClosure(resultSoFar, category, *it).toSet();
         }
     }
 
@@ -139,133 +140,130 @@ void MemberMap::calculate() const
 {
     m_closureMembers.clear();
     // run through all categories
-    for( QMap< QString,QMap<QString,StringSet> >::ConstIterator categoryIt= m_members.begin();
-         categoryIt != m_members.end(); ++categoryIt ) {
+    for (QMap<QString, QMap<QString, StringSet>>::ConstIterator categoryIt = m_members.begin();
+         categoryIt != m_members.end(); ++categoryIt) {
 
         QString category = categoryIt.key();
         QMap<QString, StringSet> groupMap = categoryIt.value();
 
         // Run through each of the groups for the given categories
-        for( QMap<QString,StringSet>::const_iterator groupIt= groupMap.constBegin()
-             ; groupIt != groupMap.constEnd()
-             ; ++groupIt )
-        {
+        for (QMap<QString, StringSet>::const_iterator groupIt = groupMap.constBegin(); groupIt != groupMap.constEnd(); ++groupIt) {
             QString group = groupIt.key();
-            if ( m_closureMembers[category].find( group ) == m_closureMembers[category].end() ) {
-                (void) calculateClosure( m_closureMembers[category], category, group );
+            if (m_closureMembers[category].find(group) == m_closureMembers[category].end()) {
+                (void)calculateClosure(m_closureMembers[category], category, group);
             }
         }
     }
     m_dirty = false;
 }
 
-void MemberMap::renameGroup( const QString& category, const QString& oldName, const QString& newName )
+void MemberMap::renameGroup(const QString &category, const QString &oldName, const QString &newName)
 {
-// Don't allow overwriting to avoid creating cycles
+    // Don't allow overwriting to avoid creating cycles
     if (m_members[category].contains(newName))
         return;
 
     m_dirty = true;
-    markDirty( category );
-    QMap<QString, StringSet>& groupMap = m_members[category];
-    groupMap.insert(newName,m_members[category][oldName] );
-    groupMap.remove( oldName );
-    for( StringSet &set: groupMap ) {
-        if ( set.contains( oldName ) ) {
-            set.remove( oldName );
-            set.insert( newName );
+    markDirty(category);
+    QMap<QString, StringSet> &groupMap = m_members[category];
+    groupMap.insert(newName, m_members[category][oldName]);
+    groupMap.remove(oldName);
+    for (StringSet &set : groupMap) {
+        if (set.contains(oldName)) {
+            set.remove(oldName);
+            set.insert(newName);
         }
     }
 }
 
-MemberMap::MemberMap( const MemberMap& other )
-    : QObject( nullptr ), m_members( other.memberMap() ), m_dirty( true ), m_loading( false )
+MemberMap::MemberMap(const MemberMap &other)
+    : QObject(nullptr)
+    , m_members(other.memberMap())
+    , m_dirty(true)
+    , m_loading(false)
 {
 }
 
-void MemberMap::deleteItem( DB::Category* category, const QString& name)
+void MemberMap::deleteItem(DB::Category *category, const QString &name)
 {
-    QMap<QString, StringSet>& groupMap = m_members[category->name()];
-    for( StringSet &items: groupMap ) {
-        items.remove( name );
+    QMap<QString, StringSet> &groupMap = m_members[category->name()];
+    for (StringSet &items : groupMap) {
+        items.remove(name);
     }
     m_members[category->name()].remove(name);
     m_dirty = true;
-    markDirty( category->name() );
+    markDirty(category->name());
 }
 
-void MemberMap::renameItem( DB::Category* category, const QString& oldName, const QString& newName )
+void MemberMap::renameItem(DB::Category *category, const QString &oldName, const QString &newName)
 {
     if (oldName == newName)
         return;
 
-    QMap<QString, StringSet>& groupMap = m_members[category->name()];
-    for( StringSet &items: groupMap ) {
-        if (items.contains( oldName ) ) {
-            items.remove( oldName );
-            items.insert( newName );
+    QMap<QString, StringSet> &groupMap = m_members[category->name()];
+    for (StringSet &items : groupMap) {
+        if (items.contains(oldName)) {
+            items.remove(oldName);
+            items.insert(newName);
         }
     }
-    if ( groupMap.contains( oldName ) ) {
+    if (groupMap.contains(oldName)) {
         groupMap[newName] = groupMap[oldName];
         groupMap.remove(oldName);
     }
     m_dirty = true;
-    markDirty( category->name() );
+    markDirty(category->name());
 }
 
-
-MemberMap& MemberMap::operator=( const MemberMap& other )
+MemberMap &MemberMap::operator=(const MemberMap &other)
 {
-    if ( this != &other ) {
+    if (this != &other) {
         m_members = other.memberMap();
         m_dirty = true;
     }
     return *this;
 }
 
-
-void MemberMap::regenerateFlatList( const QString& category )
+void MemberMap::regenerateFlatList(const QString &category)
 {
     m_flatMembers[category].clear();
-    for (QMap<QString,StringSet>::const_iterator i = m_members[category].constBegin();
+    for (QMap<QString, StringSet>::const_iterator i = m_members[category].constBegin();
          i != m_members[category].constEnd(); i++) {
         for (StringSet::const_iterator j = i.value().constBegin(); j != i.value().constEnd(); j++) {
-            m_flatMembers[category].insert( *j );
+            m_flatMembers[category].insert(*j);
         }
     }
 }
 
-void MemberMap::addMemberToGroup( const QString& category, const QString& group, const QString& item )
+void MemberMap::addMemberToGroup(const QString &category, const QString &group, const QString &item)
 {
     // Only test for cycles after database is already loaded
     if (!m_loading && !canAddMemberToGroup(category, group, item)) {
-        qCWarning(DBLog, "Inserting item %s into group %s/%s would create a cycle. Ignoring..."
-                  , qPrintable(item), qPrintable(category), qPrintable(group));
+        qCWarning(DBLog, "Inserting item %s into group %s/%s would create a cycle. Ignoring...", qPrintable(item), qPrintable(category), qPrintable(group));
         return;
     }
 
-    if ( item.isEmpty() ) {
+    if (item.isEmpty()) {
         qCWarning(DBLog, "Tried to insert null item into group %s/%s. Ignoring...", qPrintable(category), qPrintable(group));
         return;
     }
 
-
-    m_members[category][group].insert( item );
-    m_flatMembers[category].insert( item );
+    m_members[category][group].insert(item);
+    m_flatMembers[category].insert(item);
 
     if (m_loading) {
         m_dirty = true;
     } else if (!m_dirty) {
         // Update _closureMembers to avoid marking it dirty
 
-        QMap<QString, StringSet>& categoryClosure = m_closureMembers[category];
+        QMap<QString, StringSet> &categoryClosure = m_closureMembers[category];
 
         categoryClosure[group].insert(item);
 
         QMap<QString, StringSet>::const_iterator
-            closureOfItem = categoryClosure.constFind(item);
-        const StringSet* closureOfItemPtr(nullptr);
+            closureOfItem
+            = categoryClosure.constFind(item);
+        const StringSet *closureOfItemPtr(nullptr);
         if (closureOfItem != categoryClosure.constEnd()) {
             closureOfItemPtr = &(*closureOfItem);
             categoryClosure[group] += *closureOfItem;
@@ -281,31 +279,31 @@ void MemberMap::addMemberToGroup( const QString& category, const QString& group,
     }
 
     // If we are loading, we do *not* want to regenerate the list!
-    if ( !m_loading )
+    if (!m_loading)
         emit dirty();
 }
 
-void MemberMap::removeMemberFromGroup( const QString& category, const QString& group, const QString& item )
+void MemberMap::removeMemberFromGroup(const QString &category, const QString &group, const QString &item)
 {
-    Q_ASSERT( m_members.contains(category) );
-    if ( m_members[category].contains( group ) ) {
-        m_members[category][group].remove( item );
+    Q_ASSERT(m_members.contains(category));
+    if (m_members[category].contains(group)) {
+        m_members[category][group].remove(item);
         // We shouldn't be doing this very often, so just regenerate
         // the flat list
-        regenerateFlatList( category );
+        regenerateFlatList(category);
         emit dirty();
     }
 }
 
-void MemberMap::addGroup( const QString& category, const QString& group )
+void MemberMap::addGroup(const QString &category, const QString &group)
 {
-    if ( ! m_members[category].contains( group ) ) {
-        m_members[category].insert( group, StringSet() );
+    if (!m_members[category].contains(group)) {
+        m_members[category].insert(group, StringSet());
     }
-    markDirty( category );
+    markDirty(category);
 }
 
-void MemberMap::renameCategory( const QString& oldName, const QString& newName )
+void MemberMap::renameCategory(const QString &oldName, const QString &newName)
 {
     if (oldName == newName)
         return;
@@ -313,7 +311,7 @@ void MemberMap::renameCategory( const QString& oldName, const QString& newName )
     m_members.remove(oldName);
     m_closureMembers[newName] = m_closureMembers[oldName];
     m_closureMembers.remove(oldName);
-    if ( !m_loading )
+    if (!m_loading)
         emit dirty();
 }
 
@@ -321,25 +319,25 @@ void MemberMap::deleteCategory(const QString &category)
 {
     m_members.remove(category);
     m_closureMembers.remove(category);
-    markDirty( category );
+    markDirty(category);
 }
 
-QMap<QString,StringSet> DB::MemberMap::inverseMap( const QString& category ) const
+QMap<QString, StringSet> DB::MemberMap::inverseMap(const QString &category) const
 {
-    QMap<QString,StringSet> res;
-    const QMap<QString,StringSet>& map =  m_members[category];
+    QMap<QString, StringSet> res;
+    const QMap<QString, StringSet> &map = m_members[category];
 
-    for( QMap<QString,StringSet>::ConstIterator mapIt = map.begin(); mapIt != map.end(); ++mapIt ) {
+    for (QMap<QString, StringSet>::ConstIterator mapIt = map.begin(); mapIt != map.end(); ++mapIt) {
         QString group = mapIt.key();
         StringSet members = mapIt.value();
-        for( StringSet::const_iterator memberIt = members.begin(); memberIt != members.end(); ++memberIt ) {
-            res[*memberIt].insert( group );
+        for (StringSet::const_iterator memberIt = members.begin(); memberIt != members.end(); ++memberIt) {
+            res[*memberIt].insert(group);
         }
     }
     return res;
 }
 
-bool DB::MemberMap::hasPath( const QString& category, const QString& from, const QString& to ) const
+bool DB::MemberMap::hasPath(const QString &category, const QString &from, const QString &to) const
 {
     if (from == to)
         return true;
@@ -348,13 +346,13 @@ bool DB::MemberMap::hasPath( const QString& category, const QString& from, const
         return false;
     else {
         // return members(category, from, true).contains(to);
-        if ( m_dirty )
+        if (m_dirty)
             calculate();
         return m_closureMembers[category][from].contains(to);
     }
 }
 
-void DB::MemberMap::setLoading( bool b )
+void DB::MemberMap::setLoading(bool b)
 {
     if (m_loading && !b) {
         // TODO: Remove possible loaded cycles.
