@@ -16,15 +16,16 @@
    Boston, MA 02110-1301, USA.
 */
 #include "NewImageFinder.h"
+
 #include "FastDir.h"
-#include "Logging.h"
+#include "ImageDB.h"
 #include "ImageScout.h"
+#include "Logging.h"
+#include "MD5Map.h"
 
 #include <BackgroundJobs/ReadVideoLengthJob.h>
 #include <BackgroundJobs/SearchForVideosWithoutVideoThumbnailsJob.h>
 #include <BackgroundTaskManager/JobManager.h>
-#include <DB/ImageDB.h>
-#include <DB/MD5Map.h>
 #include <Exif/Database.h>
 #include <ImageManager/RawImageDecoder.h>
 #include <ImageManager/ThumbnailBuilder.h>
@@ -33,10 +34,12 @@
 #include <MainWindow/Logging.h>
 #include <MainWindow/Window.h>
 #include <Settings/SettingsData.h>
-#include <Utilities/FileUtil.h>
 #include <Utilities/FileNameUtil.h>
+#include <Utilities/FileUtil.h>
 #include <Utilities/VideoUtil.h>
 
+#include <KLocalizedString>
+#include <KMessageBox>
 #include <QApplication>
 #include <QDataStream>
 #include <QElapsedTimer>
@@ -50,9 +53,6 @@
 #include <QProgressDialog>
 #include <QStringList>
 
-#include <KLocalizedString>
-#include <KMessageBox>
-
 using namespace DB;
 
 /*****************************************************************
@@ -370,22 +370,22 @@ using namespace DB;
  *
  *****************************************************************/
 
-namespace {
+namespace
+{
 // Number of scout threads for preloading images. More than one scout thread
 // yields about 10% less performance with higher IO/sec but lower I/O throughput,
 // most probably due to thrashing.
 constexpr int IMAGE_SCOUT_THREAD_COUNT = 1;
 
-
-bool canReadImage( const DB::FileName& fileName )
+bool canReadImage(const DB::FileName &fileName)
 {
     bool fastMode = !Settings::SettingsData::instance()->ignoreFileExtension();
     QMimeDatabase::MatchMode mode = fastMode ? QMimeDatabase::MatchExtension : QMimeDatabase::MatchDefault;
     QMimeDatabase db;
-    QMimeType mimeType = db.mimeTypeForFile( fileName.absolute(), mode );
+    QMimeType mimeType = db.mimeTypeForFile(fileName.absolute(), mode);
 
-    return QImageReader::supportedMimeTypes().contains( mimeType.name().toUtf8() )
-            || ImageManager::ImageDecoder::mightDecode( fileName );
+    return QImageReader::supportedMimeTypes().contains(mimeType.name().toUtf8())
+        || ImageManager::ImageDecoder::mightDecode(fileName);
 }
 }
 
@@ -401,21 +401,21 @@ bool NewImageFinder::findImages()
     // knows about an image ? Here we've to iterate through all of them and it
     // might be more efficient do do this in the database without fetching the
     // whole info.
-    for ( const DB::FileName& fileName : DB::ImageDB::instance()->images()) {
+    for (const DB::FileName &fileName : DB::ImageDB::instance()->images()) {
         loadedFiles.insert(fileName);
     }
 
     m_pendingLoad.clear();
-    searchForNewFiles( loadedFiles, Settings::SettingsData::instance()->imageDirectory() );
+    searchForNewFiles(loadedFiles, Settings::SettingsData::instance()->imageDirectory());
     int filesToLoad = m_pendingLoad.count();
     loadExtraFiles();
 
     qCDebug(TimingLog) << "Loaded " << filesToLoad << " images in " << timer.elapsed() / 1000.0 << " seconds";
 
     // Man this is not super optimal, but will be changed onces the image finder moves to become a background task.
-    if ( MainWindow::FeatureDialog::hasVideoThumbnailer() ) {
+    if (MainWindow::FeatureDialog::hasVideoThumbnailer()) {
         BackgroundTaskManager::JobManager::instance()->addJob(
-                new BackgroundJobs::SearchForVideosWithoutVideoThumbnailsJob );
+            new BackgroundJobs::SearchForVideosWithoutVideoThumbnailsJob);
     }
 
     // To avoid deciding if the new images are shown in a given thumbnail view or in a given search
@@ -423,17 +423,16 @@ bool NewImageFinder::findImages()
     return (!m_pendingLoad.isEmpty()); // returns if new images was found.
 }
 
-
-void NewImageFinder::searchForNewFiles( const DB::FileNameSet& loadedFiles, QString directory )
+void NewImageFinder::searchForNewFiles(const DB::FileNameSet &loadedFiles, QString directory)
 {
-    qApp->processEvents( QEventLoop::AllEvents );
+    qApp->processEvents(QEventLoop::AllEvents);
     directory = Utilities::stripEndingForwardSlash(directory);
 
     const QString imageDir = Utilities::stripEndingForwardSlash(Settings::SettingsData::instance()->imageDirectory());
 
-    FastDir dir( directory );
-    const QStringList dirList = dir.entryList( );
-    ImageManager::RAWImageDecoder dec;
+    FastDir dir(directory);
+    const QStringList dirList = dir.entryList();
+    ImageManager::RAWImageDecoder rawDec;
     QStringList excluded;
     excluded << Settings::SettingsData::instance()->excludeDirectories();
     excluded = excluded.at(0).split(QString::fromLatin1(","));
@@ -444,36 +443,34 @@ void NewImageFinder::searchForNewFiles( const DB::FileNameSet& loadedFiles, QStr
     // directory, and then all subdirectories.
     QStringList subdirList;
 
-    for( QStringList::const_iterator it = dirList.constBegin(); it != dirList.constEnd(); ++it )
-    {
+    for (QStringList::const_iterator it = dirList.constBegin(); it != dirList.constEnd(); ++it) {
         const DB::FileName file = DB::FileName::fromAbsolutePath(directory + QString::fromLatin1("/") + *it);
-        if ( (*it) == QString::fromLatin1(".") || (*it) == QString::fromLatin1("..") ||
-             excluded.contains( (*it) ) || loadedFiles.contains( file ) ||
-             dec._skipThisFile(loadedFiles, file) ||
-             (*it) == QString::fromLatin1("CategoryImages") )
+        if ((*it) == QString::fromLatin1(".") || (*it) == QString::fromLatin1("..")
+            || excluded.contains((*it)) || loadedFiles.contains(file)
+            || rawDec.fileCanBeSkipped(loadedFiles, file)
+            || (*it) == QString::fromLatin1("CategoryImages"))
             continue;
 
-        QFileInfo fi( file.absolute() );
+        QFileInfo fi(file.absolute());
 
-        if ( !fi.isReadable() )
+        if (!fi.isReadable())
             continue;
-        if ( skipSymlinks && fi.isSymLink() )
+        if (skipSymlinks && fi.isSymLink())
             continue;
 
-        if ( fi.isFile() ) {
-            if ( ! DB::ImageDB::instance()->isBlocking( file ) ) {
-                if ( canReadImage(file) )
-                    m_pendingLoad.append( qMakePair( file, DB::Image ) );
-                else if ( Utilities::isVideo( file ) )
-                    m_pendingLoad.append( qMakePair( file, DB::Video ) );
+        if (fi.isFile()) {
+            if (!DB::ImageDB::instance()->isBlocking(file)) {
+                if (canReadImage(file))
+                    m_pendingLoad.append(qMakePair(file, DB::Image));
+                else if (Utilities::isVideo(file))
+                    m_pendingLoad.append(qMakePair(file, DB::Video));
             }
-        } else if ( fi.isDir() )  {
-            subdirList.append( file.absolute() );
+        } else if (fi.isDir()) {
+            subdirList.append(file.absolute());
         }
     }
-    for( QStringList::const_iterator it = subdirList.constBegin(); it != subdirList.constEnd(); ++it )
-        searchForNewFiles( loadedFiles, *it );
-
+    for (QStringList::const_iterator it = subdirList.constBegin(); it != subdirList.constEnd(); ++it)
+        searchForNewFiles(loadedFiles, *it);
 }
 
 void NewImageFinder::loadExtraFiles()
@@ -481,14 +478,14 @@ void NewImageFinder::loadExtraFiles()
     // FIXME: should be converted to a threadpool for SMP stuff and whatnot :]
     QProgressDialog dialog;
     QElapsedTimer timeSinceProgressUpdate;
-    dialog.setLabelText( i18n("<p><b>Loading information from new files</b></p>"
-                              "<p>Depending on the number of images, this may take some time.<br/>"
-                              "However, there is only a delay when new images are found.</p>") );
+    dialog.setLabelText(i18n("<p><b>Loading information from new files</b></p>"
+                             "<p>Depending on the number of images, this may take some time.<br/>"
+                             "However, there is only a delay when new images are found.</p>"));
     QProgressBar *progressBar = new QProgressBar;
-    progressBar->setFormat( QLatin1String("%v/%m") );
+    progressBar->setFormat(QLatin1String("%v/%m"));
     dialog.setBar(progressBar);
-    dialog.setMaximum( m_pendingLoad.count() );
-    dialog.setMinimumDuration( 1000 );
+    dialog.setMaximum(m_pendingLoad.count());
+    dialog.setMinimumDuration(1000);
     QAtomicInt loadedCount = 0;
 
     setupFileVersionDetection();
@@ -496,7 +493,7 @@ void NewImageFinder::loadExtraFiles()
     int count = 0;
 
     ImageScoutQueue asyncPreloadQueue;
-    for( LoadList::Iterator it = m_pendingLoad.begin(); it != m_pendingLoad.end(); ++it ) {
+    for (LoadList::Iterator it = m_pendingLoad.begin(); it != m_pendingLoad.end(); ++it) {
         asyncPreloadQueue.enqueue((*it).first);
     }
 
@@ -504,27 +501,26 @@ void NewImageFinder::loadExtraFiles()
     scout.start();
 
     Exif::Database::instance()->startInsertTransaction();
-    dialog.setValue( count ); // ensure to call setProgress(0)
+    dialog.setValue(count); // ensure to call setProgress(0)
     timeSinceProgressUpdate.start();
-    for( LoadList::Iterator it = m_pendingLoad.begin(); it != m_pendingLoad.end(); ++it, ++count ) {
-        qApp->processEvents( QEventLoop::AllEvents );
+    for (LoadList::Iterator it = m_pendingLoad.begin(); it != m_pendingLoad.end(); ++it, ++count) {
+        qApp->processEvents(QEventLoop::AllEvents);
 
-        if ( dialog.wasCanceled() )
-        {
+        if (dialog.wasCanceled()) {
             m_pendingLoad.clear();
             Exif::Database::instance()->abortInsertTransaction();
             return;
         }
         // (*it).first: DB::FileName
         // (*it).second: DB::MediaType
-        loadExtraFile( (*it).first, (*it).second );
-        loadedCount++;          // Atomic
-        if ( timeSinceProgressUpdate.elapsed() >= 1000 ) {
-            dialog.setValue( count );
+        loadExtraFile((*it).first, (*it).second);
+        loadedCount++; // Atomic
+        if (timeSinceProgressUpdate.elapsed() >= 1000) {
+            dialog.setValue(count);
             timeSinceProgressUpdate.restart();
         }
     }
-    dialog.setValue( count );
+    dialog.setValue(count);
     // loadExtraFile() has already inserted all images into the
     // database, but without committing the changes
     DB::ImageDB::instance()->commitDelayedImages();
@@ -533,7 +529,8 @@ void NewImageFinder::loadExtraFiles()
     ImageManager::ThumbnailBuilder::instance()->save();
 }
 
-void NewImageFinder::setupFileVersionDetection() {
+void NewImageFinder::setupFileVersionDetection()
+{
     // should be cached because loading once per image is expensive
     m_modifiedFileCompString = Settings::SettingsData::instance()->modifiedFileComponent();
     m_modifiedFileComponent = QRegExp(m_modifiedFileCompString);
@@ -542,25 +539,24 @@ void NewImageFinder::setupFileVersionDetection() {
     m_originalFileComponents = m_originalFileComponents.at(0).split(QString::fromLatin1(";"));
 }
 
-void NewImageFinder::loadExtraFile( const DB::FileName& newFileName, DB::MediaType type )
+void NewImageFinder::loadExtraFile(const DB::FileName &newFileName, DB::MediaType type)
 {
-    MD5 sum = MD5Sum( newFileName );
-    if ( handleIfImageHasBeenMoved(newFileName, sum) )
+    MD5 sum = MD5Sum(newFileName);
+    if (handleIfImageHasBeenMoved(newFileName, sum))
         return;
 
     // check to see if this is a new version of a previous image
     // We'll get the Exif data later, when we get the MD5 checksum.
-    ImageInfoPtr info = ImageInfoPtr(new ImageInfo( newFileName, type, false, false ));
+    ImageInfoPtr info = ImageInfoPtr(new ImageInfo(newFileName, type, false, false));
     ImageInfoPtr originalInfo;
     DB::FileName originalFileName;
 
     if (Settings::SettingsData::instance()->detectModifiedFiles()) {
         // requires at least *something* in the modifiedFileComponent
-        if (m_modifiedFileCompString.length() >= 0 &&
-            newFileName.relative().contains(m_modifiedFileComponent)) {
+        if (m_modifiedFileCompString.length() >= 0 && newFileName.relative().contains(m_modifiedFileComponent)) {
 
-            for( QStringList::const_iterator it = m_originalFileComponents.constBegin();
-                 it != m_originalFileComponents.constEnd(); ++it ) {
+            for (QStringList::const_iterator it = m_originalFileComponents.constBegin();
+                 it != m_originalFileComponents.constEnd(); ++it) {
                 QString tmp = newFileName.relative();
                 tmp.replace(m_modifiedFileComponent, (*it));
                 originalFileName = DB::FileName::fromRelativePath(tmp);
@@ -568,8 +564,8 @@ void NewImageFinder::loadExtraFile( const DB::FileName& newFileName, DB::MediaTy
                 MD5 originalSum;
                 if (newFileName == originalFileName)
                     originalSum = sum;
-                else if (DB::ImageDB::instance()->md5Map()->containsFile( originalFileName ) )
-                    originalSum = DB::ImageDB::instance()->md5Map()->lookupFile( originalFileName );
+                else if (DB::ImageDB::instance()->md5Map()->containsFile(originalFileName))
+                    originalSum = DB::ImageDB::instance()->md5Map()->lookupFile(originalFileName);
                 else
                     // Do *not* attempt to compute the checksum here.  It forces a filesystem
                     // lookup on a file that may not exist and substantially degrades
@@ -577,31 +573,29 @@ void NewImageFinder::loadExtraFile( const DB::FileName& newFileName, DB::MediaTy
                     // If one of these other files exist, it will be found later in
                     // the image search at which point we'll detect the modified file.
                     continue;
-                if ( DB::ImageDB::instance()->md5Map()->contains( originalSum ) ) {
+                if (DB::ImageDB::instance()->md5Map()->contains(originalSum)) {
                     // we have a previous copy of this file; copy it's data
                     // from the original.
-                    originalInfo = DB::ImageDB::instance()->info( originalFileName );
-                    if ( !originalInfo ) {
+                    originalInfo = DB::ImageDB::instance()->info(originalFileName);
+                    if (!originalInfo) {
                         qCDebug(DBLog) << "Original info not found by name for " << originalFileName.absolute() << ", trying by MD5 sum.";
-                        originalFileName = DB::ImageDB::instance()->md5Map()->lookup( originalSum );
+                        originalFileName = DB::ImageDB::instance()->md5Map()->lookup(originalSum);
 
-                        if (!originalFileName.isNull())
-                        {
+                        if (!originalFileName.isNull()) {
                             qCDebug(DBLog) << "Substitute image " << originalFileName.absolute() << " found.";
-                            originalInfo = DB::ImageDB::instance()->info( originalFileName );
+                            originalInfo = DB::ImageDB::instance()->info(originalFileName);
                         }
 
-                        if ( !originalInfo )
-                        {
-                            qCWarning(DBLog,"How did that happen? We couldn't find info for the original image %s; can't copy the original data to %s",
-                                     qPrintable(originalFileName.absolute()), qPrintable(newFileName.absolute()));
+                        if (!originalInfo) {
+                            qCWarning(DBLog, "How did that happen? We couldn't find info for the original image %s; can't copy the original data to %s",
+                                      qPrintable(originalFileName.absolute()), qPrintable(newFileName.absolute()));
                             continue;
                         }
                     }
                     info->copyExtraData(*originalInfo);
 
                     /* if requested to move, then delete old data from original */
-                    if (Settings::SettingsData::instance()->moveOriginalContents() ) {
+                    if (Settings::SettingsData::instance()->moveOriginalContents()) {
                         originalInfo->removeExtraData();
                     }
 
@@ -611,15 +605,14 @@ void NewImageFinder::loadExtraFile( const DB::FileName& newFileName, DB::MediaTy
         }
     }
     ImageInfoList newImages;
-    newImages.append( info );
-    DB::ImageDB::instance()->addImages( newImages, false );
+    newImages.append(info);
+    DB::ImageDB::instance()->addImages(newImages, false);
 
     // also inserts image into exif db if present:
-    info->setMD5Sum( sum );
-    DB::ImageDB::instance()->md5Map()->insert( sum, info->fileName());
+    info->setMD5Sum(sum);
+    DB::ImageDB::instance()->md5Map()->insert(sum, info->fileName());
 
-    if (originalInfo &&
-        Settings::SettingsData::instance()->autoStackNewFiles() ) {
+    if (originalInfo && Settings::SettingsData::instance()->autoStackNewFiles()) {
 
         // stack the files together
         DB::FileName olderfile = originalFileName;
@@ -630,11 +623,11 @@ void NewImageFinder::loadExtraFile( const DB::FileName& newFileName, DB::MediaTy
         tostack.append(newerfile);
 
         DB::FileNameList oldStack;
-        if ( ( oldStack = DB::ImageDB::instance()->getStackFor( olderfile)).isEmpty() ) {
+        if ((oldStack = DB::ImageDB::instance()->getStackFor(olderfile)).isEmpty()) {
             tostack.append(olderfile);
         } else {
-            for ( const DB::FileName& tmp : oldStack ) {
-                tostack.append( tmp );
+            for (const DB::FileName &tmp : oldStack) {
+                tostack.append(tmp);
             }
         }
         DB::ImageDB::instance()->stack(tostack);
@@ -645,43 +638,42 @@ void NewImageFinder::loadExtraFile( const DB::FileName& newFileName, DB::MediaTy
     }
 
     markUnTagged(info);
-    ImageManager::ThumbnailBuilder::instance()->buildOneThumbnail( info );
-    if ( info->isVideo() && MainWindow::FeatureDialog::hasVideoThumbnailer() ) {
+    ImageManager::ThumbnailBuilder::instance()->buildOneThumbnail(info);
+    if (info->isVideo() && MainWindow::FeatureDialog::hasVideoThumbnailer()) {
         // needs to be done *after* insertion into database
         BackgroundTaskManager::JobManager::instance()->addJob(
-                    new BackgroundJobs::ReadVideoLengthJob(info->fileName(), BackgroundTaskManager::BackgroundVideoPreviewRequest));
+            new BackgroundJobs::ReadVideoLengthJob(info->fileName(), BackgroundTaskManager::BackgroundVideoPreviewRequest));
     }
 }
 
-bool NewImageFinder::handleIfImageHasBeenMoved(const FileName &newFileName, const MD5& sum)
+bool NewImageFinder::handleIfImageHasBeenMoved(const FileName &newFileName, const MD5 &sum)
 {
-    if ( DB::ImageDB::instance()->md5Map()->contains( sum ) ) {
+    if (DB::ImageDB::instance()->md5Map()->contains(sum)) {
         const DB::FileName matchedFileName = DB::ImageDB::instance()->md5Map()->lookup(sum);
-        QFileInfo fi( matchedFileName.absolute() );
+        QFileInfo fi(matchedFileName.absolute());
 
-        if ( !fi.exists() ) {
+        if (!fi.exists()) {
             // The file we had a collapse with didn't exists anymore so it is likely moved to this new name
-            ImageInfoPtr info = DB::ImageDB::instance()->info( matchedFileName);
-            if ( !info )
+            ImageInfoPtr info = DB::ImageDB::instance()->info(matchedFileName);
+            if (!info)
                 qCWarning(DBLog, "How did that happen? We couldn't find info for the images %s", qPrintable(matchedFileName.relative()));
             else {
-                info->delaySavingChanges(true);
-                fi = QFileInfo ( matchedFileName.relative() );
-                if ( info->label() == fi.completeBaseName() ) {
-                    fi = QFileInfo( newFileName.absolute() );
-                    info->setLabel( fi.completeBaseName() );
+                fi = QFileInfo(matchedFileName.relative());
+                if (info->label() == fi.completeBaseName()) {
+                    fi = QFileInfo(newFileName.absolute());
+                    info->setLabel(fi.completeBaseName());
                 }
 
-                DB::ImageDB::instance()->renameImage( info, newFileName );
+                DB::ImageDB::instance()->renameImage(info, newFileName);
 
                 // We need to insert the new name into the MD5 map,
                 // as it is a map, the value for the moved file will automatically be deleted.
 
-                DB::ImageDB::instance()->md5Map()->insert( sum, info->fileName());
+                DB::ImageDB::instance()->md5Map()->insert(sum, info->fileName());
 
-                Exif::Database::instance()->remove( matchedFileName );
-                Exif::Database::instance()->add( newFileName);
-                ImageManager::ThumbnailBuilder::instance()->buildOneThumbnail( info );
+                Exif::Database::instance()->remove(matchedFileName);
+                Exif::Database::instance()->add(newFileName);
+                ImageManager::ThumbnailBuilder::instance()->buildOneThumbnail(info);
                 return true;
             }
         }
@@ -689,68 +681,68 @@ bool NewImageFinder::handleIfImageHasBeenMoved(const FileName &newFileName, cons
     return false; // The image wasn't just moved
 }
 
-bool  NewImageFinder::calculateMD5sums(
-    const DB::FileNameList& list,
-    DB::MD5Map* md5Map,
-    bool* wasCanceled)
+bool NewImageFinder::calculateMD5sums(
+    const DB::FileNameList &list,
+    DB::MD5Map *md5Map,
+    bool *wasCanceled)
 {
     // FIXME: should be converted to a threadpool for SMP stuff and whatnot :]
     QProgressDialog dialog;
     dialog.setLabelText(
-        i18np("<p><b>Calculating checksum for %1 file</b></p>","<p><b>Calculating checksums for %1 files</b></p>", list.size())
+        i18np("<p><b>Calculating checksum for %1 file</b></p>", "<p><b>Calculating checksums for %1 files</b></p>", list.size())
         + i18n("<p>By storing a checksum for each image "
-             "KPhotoAlbum is capable of finding images "
-             "even when you have moved them on the disk.</p>"));
+               "KPhotoAlbum is capable of finding images "
+               "even when you have moved them on the disk.</p>"));
     dialog.setMaximum(list.size());
-    dialog.setMinimumDuration( 1000 );
+    dialog.setMinimumDuration(1000);
 
     int count = 0;
     DB::FileNameList cantRead;
     bool dirty = false;
 
-    for (const FileName& fileName : list) {
-        if ( count % 10 == 0 ) {
-            dialog.setValue( count ); // ensure to call setProgress(0)
-            qApp->processEvents( QEventLoop::AllEvents );
+    for (const FileName &fileName : list) {
+        if (count % 10 == 0) {
+            dialog.setValue(count); // ensure to call setProgress(0)
+            qApp->processEvents(QEventLoop::AllEvents);
 
-            if ( dialog.wasCanceled() ) {
-                if ( wasCanceled )
+            if (dialog.wasCanceled()) {
+                if (wasCanceled)
                     *wasCanceled = true;
                 return dirty;
             }
         }
 
-        MD5 md5 = MD5Sum( fileName );
+        MD5 md5 = MD5Sum(fileName);
         if (md5.isNull()) {
             cantRead << fileName;
             continue;
         }
 
         ImageInfoPtr info = ImageDB::instance()->info(fileName);
-        if  ( info->MD5Sum() != md5 ) {
-            info->setMD5Sum( md5 );
+        if (info->MD5Sum() != md5) {
+            info->setMD5Sum(md5);
             dirty = true;
             ImageManager::ThumbnailCache::instance()->removeThumbnail(fileName);
         }
 
-        md5Map->insert( md5, fileName );
+        md5Map->insert(md5, fileName);
 
         ++count;
     }
-    if ( wasCanceled )
+    if (wasCanceled)
         *wasCanceled = false;
 
-    if ( !cantRead.empty() )
-        KMessageBox::informationList( nullptr, i18n("Following files could not be read:"), cantRead.toStringList(DB::RelativeToImageRoot) );
+    if (!cantRead.empty())
+        KMessageBox::informationList(nullptr, i18n("Following files could not be read:"), cantRead.toStringList(DB::RelativeToImageRoot));
 
     return dirty;
 }
 
-void DB::NewImageFinder::markUnTagged( ImageInfoPtr info )
+void DB::NewImageFinder::markUnTagged(ImageInfoPtr info)
 {
-    if ( Settings::SettingsData::instance()->hasUntaggedCategoryFeatureConfigured() ) {
-        info->addCategoryInfo( Settings::SettingsData::instance()->untaggedCategory(),
-                           Settings::SettingsData::instance()->untaggedTag() );
+    if (Settings::SettingsData::instance()->hasUntaggedCategoryFeatureConfigured()) {
+        info->addCategoryInfo(Settings::SettingsData::instance()->untaggedCategory(),
+                              Settings::SettingsData::instance()->untaggedTag());
     }
 }
 // vi:expandtab:tabstop=4 shiftwidth=4:
