@@ -1,4 +1,4 @@
-/* Copyright (C) 2012 Jesper K. Pedersen <blackie@kde.org>
+/* Copyright (C) 2012-2019 The KPhotoAlbum Development Team
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -18,46 +18,54 @@
 #ifndef EXIF_GRID_H
 #define EXIF_GRID_H
 
-#include <QScrollArea>
 #include <DB/FileName.h>
 #include <Utilities/StringSet.h>
+
 #include <QMap>
+#include <QScrollArea>
 
 class QLabel;
 
 using Utilities::StringSet;
 
-namespace Exif {
+namespace Exif
+{
 
-class Grid :public QScrollArea
+class Grid : public QScrollArea
 {
     Q_OBJECT
 
 public:
-    explicit Grid( QWidget* parent );
-    void setFileName( const DB::FileName& fileName );
+    explicit Grid(QWidget *parent);
+    void setFileName(const DB::FileName &fileName);
 
 public slots:
-    void updateSearchString( const QString& );
+    void updateSearchString(const QString &);
+    /**
+     * @brief setupUI sets up the scroll area for the given charset.
+     * Usually, this slot is only indirectly called through the setFileName function,
+     * but calling it directly can be used to change the display character set without changing the file name.
+     * @param charset
+     */
+    void setupUI(const QString &charset);
 
 private:
-    void keyPressEvent( QKeyEvent* ) override;
-    bool eventFilter(QObject*, QEvent*) override;
+    void keyPressEvent(QKeyEvent *) override;
+    bool eventFilter(QObject *, QEvent *) override;
 
-    StringSet exifGroups( const QMap<QString, QStringList>& exifInfo );
-    QMap<QString,QStringList> itemsForGroup( const QString& group, const QMap<QString, QStringList>& exifInfo );
-    QString groupName( const QString& exifName );
-    QString exifNameNoGroup( const QString& fullName );
+    StringSet exifGroups(const QMap<QString, QStringList> &exifInfo);
+    QMap<QString, QStringList> itemsForGroup(const QString &group, const QMap<QString, QStringList> &exifInfo);
+    QString groupName(const QString &exifName);
+    QString exifNameNoGroup(const QString &fullName);
     void scroll(int dy);
-    QLabel* headerLabel(const QString& title);
-    QPair<QLabel*,QLabel*> infoLabelPair(const QString& title, const QString& value, const QColor& color);
+    QLabel *headerLabel(const QString &title);
+    QPair<QLabel *, QLabel *> infoLabelPair(const QString &title, const QString &value, const QColor &color);
 
 private slots:
-    void setupUI( const QString& charset );
     void updateWidgetSize();
 
 private:
-    QList< QPair<QLabel*,QLabel*> > m_labels;
+    QList<QPair<QLabel *, QLabel *>> m_labels;
     int m_maxKeyWidth;
     DB::FileName m_fileName;
 };
