@@ -17,9 +17,11 @@
 */
 
 #include "CancelEvent.h"
+
 #include "ImageRequest.h"
-ImageManager::CancelEvent::CancelEvent( ImageRequest* request )
-    : QEvent( static_cast<QEvent::Type>(CANCELEVENTID)), m_request( request )
+ImageManager::CancelEvent::CancelEvent(ImageRequest *request)
+    : QEvent(static_cast<QEvent::Type>(CANCELEVENTID))
+    , m_request(request)
 {
 }
 
@@ -28,7 +30,7 @@ ImageManager::CancelEvent::~CancelEvent()
     delete m_request;
 }
 
-ImageManager::ImageRequest * ImageManager::CancelEvent::request() const
+ImageManager::ImageRequest *ImageManager::CancelEvent::request() const
 {
     return m_request;
 }
