@@ -18,31 +18,30 @@
 
 #ifndef CATEGORYIMAGEPOPUP_H
 #define CATEGORYIMAGEPOPUP_H
-#include <QMenu>
-#include <QImage>
-#include "DB/ImageDB.h"
+#include <DB/ImageDB.h>
 
+#include <QImage>
+#include <QMenu>
 
 namespace MainWindow
 {
 
-
-class CategoryImagePopup :public QMenu {
+class CategoryImagePopup : public QMenu
+{
     Q_OBJECT
 
 public:
-    explicit CategoryImagePopup( QWidget* parent );
-    void populate( const QImage& image, const DB::FileName& imageName );
+    explicit CategoryImagePopup(QWidget *parent);
+    void populate(const QImage &image, const DB::FileName &imageName);
 
 protected slots:
-    void slotExecuteService( QAction* );
+    void slotExecuteService(QAction *);
     void makeCategoryImage();
 
 private:
     QImage m_image;
     DB::ImageInfoPtr m_imageInfo;
 };
-
 }
 
 #endif /* CATEGORYIMAGEPOPUP_H */
