@@ -18,19 +18,17 @@
 
 #ifndef MAINWINDOW_WINDOW_H
 #define MAINWINDOW_WINDOW_H
-#include <config-kpa-kipi.h>
-
-#include <QList>
-#include <QPointer>
-#include <QUrl>
-
-#include <KXmlGuiWindow>
-
 #include <DB/Category.h>
 #include <DB/FileNameList.h>
 #include <DB/ImageSearchInfo.h>
 #include <DB/UIDelegate.h>
 #include <ThumbnailView/enums.h>
+
+#include <KXmlGuiWindow>
+#include <QList>
+#include <QPointer>
+#include <QUrl>
+#include <config-kpa-kipi.h>
 #ifdef HAVE_KGEOMAP
 #include <Browser/PositionBrowserWidget.h>
 #endif
@@ -50,17 +48,45 @@ class KTipDialog;
 class KToggleAction;
 
 #ifdef HASKIPI
-namespace KIPI { class PluginLoader; }
+namespace KIPI
+{
+class PluginLoader;
+}
 #endif
 
-namespace AnnotationDialog { class Dialog; }
-namespace Browser{ class BrowserWidget; class BreadcrumbList; }
-namespace DateBar { class DateBarWidget; }
-namespace DB { class ImageInfoList; }
-namespace HTMLGenerator { class HTMLDialog; }
-namespace Plugins { class Interface; }
-namespace Settings { class SettingsDialog; }
-namespace ThumbnailView { class ThumbnailFacade; }
+namespace AnnotationDialog
+{
+class Dialog;
+}
+namespace Browser
+{
+class BrowserWidget;
+class BreadcrumbList;
+}
+namespace DateBar
+{
+class DateBarWidget;
+}
+namespace DB
+{
+class ImageInfoList;
+}
+namespace HTMLGenerator
+{
+class HTMLDialog;
+}
+namespace Plugins
+{
+class Interface;
+}
+namespace Settings
+{
+class SettingsDialog;
+}
+namespace ThumbnailView
+{
+class ThumbnailFacade;
+}
 
 class BreadcrumbViewer;
 
@@ -70,25 +96,24 @@ class DeleteDialog;
 class StatusBar;
 class TokenEditor;
 
-class Window :public KXmlGuiWindow
-        , public DB::UIDelegate
+class Window : public KXmlGuiWindow, public DB::UIDelegate
 {
     Q_OBJECT
 
 public:
-    explicit Window( QWidget* parent );
+    explicit Window(QWidget *parent);
     ~Window() override;
-    static void configureImages( const DB::ImageInfoList& list, bool oneAtATime );
-    static Window* theMainWindow();
-    DB::FileNameList selected( ThumbnailView::SelectionMode mode = ThumbnailView::ExpandCollapsedStacks ) const;
+    static void configureImages(const DB::ImageInfoList &list, bool oneAtATime);
+    static Window *theMainWindow();
+    DB::FileNameList selected(ThumbnailView::SelectionMode mode = ThumbnailView::ExpandCollapsedStacks) const;
     DB::ImageSearchInfo currentContext();
     QString currentBrowseCategory() const;
-    void setStackHead( const DB::FileName& image );
-    void setHistogramVisibilty( bool visible ) const;
+    void setStackHead(const DB::FileName &image);
+    void setHistogramVisibilty(bool visible) const;
     bool dbIsDirty() const;
 #ifdef HAVE_KGEOMAP
     void showPositionBrowser();
-    Browser::PositionBrowserWidget* positionBrowserWidget();
+    Browser::PositionBrowserWidget *positionBrowserWidget();
 #endif
 
     // implement UI delegate interface
@@ -104,11 +129,11 @@ public:
     bool isDialogDisabled(const QString &dialogId) override;
 
 public slots:
-    void showThumbNails(const DB::FileNameList& items);
-    void loadPlugins();
-    void reloadThumbnails( ThumbnailView::SelectionUpdateMethod method = ThumbnailView::MaintainSelection );
+    void showThumbNails(const DB::FileNameList &items);
+    void loadKipiPlugins();
+    void reloadThumbnails(ThumbnailView::SelectionUpdateMethod method = ThumbnailView::MaintainSelection);
     void runDemo();
-    void slotImageRotated(const DB::FileName& fileName);
+    void slotImageRotated(const DB::FileName &fileName);
     void slotSave();
 
 protected slots:
@@ -126,7 +151,9 @@ protected slots:
     void slotReReadExifInfo();
     void slotAutoStackImages();
     void slotSearch();
-    void slotView( bool reuse = true, bool slideShow = false, bool random = false );
+    // FIXME(jzarl): improve this function signature:
+    void slotView(bool reuse, bool slideShow = false, bool random = false);
+    void slotView();
     void slotViewNewWindow();
     void slotSortByDateAndTime();
     void slotSortAllByDateAndTime();
@@ -142,9 +169,9 @@ protected slots:
     void unlockFromDefaultScope();
     void changePassword();
     void slotConfigureKeyBindings();
-    void slotSetFileName( const DB::FileName& );
+    void slotSetFileName(const DB::FileName &);
     void updateContextMenuFromSelectionSize(int selectionSize);
-    void slotUpdateViewMenu( DB::Category::ViewType );
+    void slotUpdateViewMenu(DB::Category::ViewType);
     void slotShowNotOnDisk();
     void slotBuildThumbnails();
     void slotBuildThumbnailsIfWanted();
@@ -156,29 +183,29 @@ protected slots:
     void slotExport();
     void delayedInit();
     void slotReenableMessages();
-    void slotImagesChanged( const QList<QUrl>& );
+    void slotImagesChanged(const QList<QUrl> &);
     void slotSelectionChanged(int count);
     void plug();
     void slotRemoveTokens();
     void slotShowListOfFiles();
-    void updateDateBar( const Browser::BreadcrumbList& );
+    void updateDateBar(const Browser::BreadcrumbList &);
     void updateDateBar();
     void slotShowImagesWithInvalidDate();
     void slotShowImagesWithChangedMD5Sum();
-    void showDateBarTip( const QString& );
+    void showDateBarTip(const QString &);
     void slotJumpToContext();
-    void setDateRange( const DB::ImageDate& );
+    void setDateRange(const DB::ImageDate &);
     void clearDateRange();
     void startAutoSaveTimer();
     void slotRecalcCheckSums();
     void slotShowExifInfo();
     void showFeatures();
-    void showImage( const DB::FileName& fileName );
+    void showImage(const DB::FileName &fileName);
     void slotOrderIncr();
     void slotOrderDecr();
     void slotRotateSelectedLeft();
     void slotRotateSelectedRight();
-    void rotateSelected( int angle );
+    void rotateSelected(int angle);
     void showVideos();
     void slotStatistics();
     void slotRecreateExifDB();
@@ -189,90 +216,90 @@ protected slots:
     void slotMarkUntagged();
 
 protected:
-    void configureImages( bool oneAtATime );
+    void configureImages(bool oneAtATime);
     QString welcome();
-    void closeEvent( QCloseEvent* e ) override;
-    void resizeEvent( QResizeEvent* ) override;
-    void moveEvent ( QMoveEvent * ) override;
+    void closeEvent(QCloseEvent *e) override;
+    void resizeEvent(QResizeEvent *) override;
+    void moveEvent(QMoveEvent *) override;
     void setupMenuBar();
     void createAnnotationDialog();
     bool load();
-    void contextMenuEvent( QContextMenuEvent* e ) override;
-    void setLocked( bool b, bool force, bool recount=true );
-    void configImages( const DB::ImageInfoList& list, bool oneAtATime );
-    void updateStates( bool thumbNailView );
+    void contextMenuEvent(QContextMenuEvent *e) override;
+    void setLocked(bool b, bool force, bool recount = true);
+    void configImages(const DB::ImageInfoList &list, bool oneAtATime);
+    void updateStates(bool thumbNailView);
     DB::FileNameList selectedOnDisk();
     void setupPluginMenu();
-    void launchViewer(const DB::FileNameList& mediaList, bool reuse, bool slideShow, bool random);
+    void launchViewer(const DB::FileNameList &mediaList, bool reuse, bool slideShow, bool random);
     void setupStatusBar();
-    void setPluginMenuState( const char* name, const QList<QAction*>& actions );
+    void setPluginMenuState(const char *name, const QList<QAction *> &actions);
     void createSearchBar();
     void executeStartupActions();
     void checkIfVideoThumbnailerIsInstalled();
     bool anyVideosSelected() const;
 #ifdef HAVE_KGEOMAP
-    Browser::PositionBrowserWidget* createPositionBrowser();
+    Browser::PositionBrowserWidget *createPositionBrowser();
 #endif
 
 private:
-    static Window* s_instance;
+    static Window *s_instance;
 
-    ThumbnailView::ThumbnailFacade* m_thumbnailView;
-    Settings::SettingsDialog* m_settingsDialog;
+    ThumbnailView::ThumbnailFacade *m_thumbnailView;
+    Settings::SettingsDialog *m_settingsDialog;
     QPointer<AnnotationDialog::Dialog> m_annotationDialog;
-    QStackedWidget* m_stack;
-    QTimer* m_autoSaveTimer;
-    Browser::BrowserWidget* m_browser;
-    DeleteDialog* m_deleteDialog;
-    QAction* m_lock;
-    QAction* m_unlock;
-    QAction* m_setDefaultPos;
-    QAction* m_setDefaultNeg;
-    QAction* m_jumpToContext;
-    HTMLGenerator::HTMLDialog* m_htmlDialog;
-    QAction* m_configOneAtATime;
-    QAction* m_configAllSimultaniously;
-    QAction* m_createImageStack;
-    QAction* m_unStackImages;
-    QAction* m_setStackHead;
-    QAction* m_view;
-    QAction* m_rotLeft;
-    QAction* m_rotRight;
-    QAction* m_sortByDateAndTime;
-    QAction* m_sortAllByDateAndTime;
-    QAction* m_AutoStackImages;
-    QAction* m_viewInNewWindow;
-    KActionMenu* m_viewMenu;
-    KToggleAction* m_smallListView;
-    KToggleAction* m_largeListView;
-    KToggleAction* m_largeIconView;
-    QAction* m_generateHtml;
-    QAction* m_copy;
-    QAction* m_paste;
-    QAction* m_deleteSelected;
-    QAction* m_limitToMarked;
-    QAction* m_selectAll;
-    QAction* m_clearSelection;
-    QAction* m_runSlideShow;
-    QAction* m_runRandomSlideShow;
-    Plugins::Interface* m_pluginInterface;
-    QAction* m_showExifDialog;
+    QStackedWidget *m_stack;
+    QTimer *m_autoSaveTimer;
+    Browser::BrowserWidget *m_browser;
+    DeleteDialog *m_deleteDialog;
+    QAction *m_lock;
+    QAction *m_unlock;
+    QAction *m_setDefaultPos;
+    QAction *m_setDefaultNeg;
+    QAction *m_jumpToContext;
+    HTMLGenerator::HTMLDialog *m_htmlDialog;
+    QAction *m_configOneAtATime;
+    QAction *m_configAllSimultaniously;
+    QAction *m_createImageStack;
+    QAction *m_unStackImages;
+    QAction *m_setStackHead;
+    QAction *m_view;
+    QAction *m_rotLeft;
+    QAction *m_rotRight;
+    QAction *m_sortByDateAndTime;
+    QAction *m_sortAllByDateAndTime;
+    QAction *m_AutoStackImages;
+    QAction *m_viewInNewWindow;
+    KActionMenu *m_viewMenu;
+    KToggleAction *m_smallListView;
+    KToggleAction *m_largeListView;
+    KToggleAction *m_largeIconView;
+    QAction *m_generateHtml;
+    QAction *m_copy;
+    QAction *m_paste;
+    QAction *m_deleteSelected;
+    QAction *m_limitToMarked;
+    QAction *m_selectAll;
+    QAction *m_clearSelection;
+    QAction *m_runSlideShow;
+    QAction *m_runRandomSlideShow;
+    Plugins::Interface *m_pluginInterface;
+    QAction *m_showExifDialog;
 #ifdef HASKIPI
-    KIPI::PluginLoader* m_pluginLoader;
+    KIPI::PluginLoader *m_pluginLoader;
 #endif
-    QAction* m_recreateThumbnails;
-    QAction* m_useNextVideoThumbnail;
-    QAction* m_usePreviousVideoThumbnail;
-    QAction* m_markUntagged;
-    TokenEditor* m_tokenEditor;
-    DateBar::DateBarWidget* m_dateBar;
-    QFrame* m_dateBarLine;
-    bool m_hasLoadedPlugins;
-    QMap<Qt::Key, QPair<QString,QString> > m_viewerInputMacros;
-    MainWindow::StatusBar* m_statusBar;
+    QAction *m_recreateThumbnails;
+    QAction *m_useNextVideoThumbnail;
+    QAction *m_usePreviousVideoThumbnail;
+    QAction *m_markUntagged;
+    TokenEditor *m_tokenEditor;
+    DateBar::DateBarWidget *m_dateBar;
+    QFrame *m_dateBarLine;
+    bool m_hasLoadedKipiPlugins;
+    QMap<Qt::Key, QPair<QString, QString>> m_viewerInputMacros;
+    MainWindow::StatusBar *m_statusBar;
     QString m_lastTarget;
 #ifdef HAVE_KGEOMAP
-    Browser::PositionBrowserWidget* m_positionBrowser;
+    Browser::PositionBrowserWidget *m_positionBrowser;
 #endif
 };
 
