@@ -20,12 +20,12 @@
 // libkgeomap includes
 
 // Local includes
-#include <Map/MapView.h>
+#include "MapView.h"
 
 Map::SearchMarkerTiler::SearchMarkerTiler(KGeoMap::ModelHelper *const modelHelper, QObject *const parent)
-    : ItemMarkerTiler(modelHelper,parent)
+    : ItemMarkerTiler(modelHelper, parent)
 {
-    m_mapView = dynamic_cast<MapView*>(parent);
+    m_mapView = dynamic_cast<MapView *>(parent);
 }
 
 Map::SearchMarkerTiler::~SearchMarkerTiler()
