@@ -19,21 +19,22 @@
 #ifndef MYIMAGECOLLECTION_H
 #define MYIMAGECOLLECTION_H
 
-#include <config-kpa-kipi.h>
+#include <DB/ImageInfoList.h>
 
 #include <KIPI/ImageCollectionShared>
-
-#include <DB/ImageInfoList.h>
+#include <config-kpa-kipi.h>
 
 namespace Plugins
 {
 
-class ImageCollection :public KIPI::ImageCollectionShared
+class ImageCollection : public KIPI::ImageCollectionShared
 {
 public:
-    enum Type { CurrentAlbum, CurrentSelection, SubClass };
+    enum Type { CurrentAlbum,
+                CurrentSelection,
+                SubClass };
 
-    explicit ImageCollection( Type tp );
+    explicit ImageCollection(Type tp);
 
     QString name() override;
     QList<QUrl> images() override;
@@ -47,8 +48,8 @@ public:
     // isDirectory
 
 protected:
-    QList<QUrl> imageListToUrlList( const DB::ImageInfoList& list );
-    QList<QUrl> stringListToUrlList( const QStringList& list );
+    QList<QUrl> imageListToUrlList(const DB::ImageInfoList &list);
+    QList<QUrl> stringListToUrlList(const QStringList &list);
     QUrl commonRoot();
 
 private:
