@@ -18,9 +18,10 @@
 #ifndef MYIMAGECOLLECTIONSELECTOR_H
 #define MYIMAGECOLLECTIONSELECTOR_H
 
+#include "ImageCollection.h"
+#include "Interface.h"
+
 #include <config-kpa-kipi.h>
-#include "Plugins/ImageCollection.h"
-#include "Plugins/Interface.h"
 
 namespace Plugins
 {
@@ -38,7 +39,7 @@ namespace Plugins
  *    useful as i.e. html export plugin uses the names of image collections as headlines and groups the images visually by
  *    image collection.
  */
-class ImageCollectionSelector :public KIPI::ImageCollectionSelector
+class ImageCollectionSelector : public KIPI::ImageCollectionSelector
 {
 public:
     ImageCollectionSelector(QWidget *parent, Interface *interface);
