@@ -17,86 +17,86 @@
 */
 
 #include "ImageInfo.h"
+
 #include "Logging.h"
 
-#include <QFileInfo>
-#include <QList>
-
-#include <DB/CategoryCollection.h>
 #include <DB/Category.h>
+#include <DB/CategoryCollection.h>
 #include <DB/CategoryPtr.h>
 #include <DB/ImageDB.h>
 #include <DB/ImageInfo.h>
 #include <DB/MemberMap.h>
 #include <MainWindow/DirtyIndicator.h>
 
-#define KEXIV_ORIENTATION_UNSPECIFIED   0
-#define KEXIV_ORIENTATION_NORMAL        1
-#define KEXIV_ORIENTATION_HFLIP         2
-#define KEXIV_ORIENTATION_ROT_180       3
-#define KEXIV_ORIENTATION_VFLIP         4
-#define KEXIV_ORIENTATION_ROT_90_HFLIP  5
-#define KEXIV_ORIENTATION_ROT_90        6
-#define KEXIV_ORIENTATION_ROT_90_VFLIP  7
-#define KEXIV_ORIENTATION_ROT_270       8
+#include <QFileInfo>
+#include <QList>
+
+#define KEXIV_ORIENTATION_UNSPECIFIED 0
+#define KEXIV_ORIENTATION_NORMAL 1
+#define KEXIV_ORIENTATION_HFLIP 2
+#define KEXIV_ORIENTATION_ROT_180 3
+#define KEXIV_ORIENTATION_VFLIP 4
+#define KEXIV_ORIENTATION_ROT_90_HFLIP 5
+#define KEXIV_ORIENTATION_ROT_90 6
+#define KEXIV_ORIENTATION_ROT_90_VFLIP 7
+#define KEXIV_ORIENTATION_ROT_270 8
 /**
  * Convert a rotation in degrees to a KExiv2::ImageOrientation value.
  */
-static int deg2KexivOrientation( int deg)
+static int deg2KexivOrientation(int deg)
 {
-    deg = (deg + 360) % 360;;
-    switch (deg)
-    {
-        case 0:
-            return KEXIV_ORIENTATION_NORMAL;
-        case 90:
-            return KEXIV_ORIENTATION_ROT_90;
-        case 180:
-            return KEXIV_ORIENTATION_ROT_180;
-        case 270:
-            return KEXIV_ORIENTATION_ROT_270;
-        default:
-            qCWarning(PluginsLog) << "Rotation of " << deg << "degrees can't be mapped to KExiv2::ImageOrientation value.";
-            return KEXIV_ORIENTATION_UNSPECIFIED;
+    deg = (deg + 360) % 360;
+    ;
+    switch (deg) {
+    case 0:
+        return KEXIV_ORIENTATION_NORMAL;
+    case 90:
+        return KEXIV_ORIENTATION_ROT_90;
+    case 180:
+        return KEXIV_ORIENTATION_ROT_180;
+    case 270:
+        return KEXIV_ORIENTATION_ROT_270;
+    default:
+        qCWarning(PluginsLog) << "Rotation of " << deg << "degrees can't be mapped to KExiv2::ImageOrientation value.";
+        return KEXIV_ORIENTATION_UNSPECIFIED;
     }
 }
 /**
  * Convert a KExiv2::ImageOrientation value into a degrees angle.
  */
-static int kexivOrientation2deg( int orient)
+static int kexivOrientation2deg(int orient)
 {
-    switch (orient)
-    {
-        case KEXIV_ORIENTATION_NORMAL:
-            return 0;
-        case KEXIV_ORIENTATION_ROT_90:
-            return 90;
-        case KEXIV_ORIENTATION_ROT_180:
-            return 280;
-        case KEXIV_ORIENTATION_ROT_270:
-            return 270;
-        default:
-            qCWarning(PluginsLog) << "KExiv2::ImageOrientation value " << orient << " not a pure rotation. Discarding orientation info.";
-            return 0;
+    switch (orient) {
+    case KEXIV_ORIENTATION_NORMAL:
+        return 0;
+    case KEXIV_ORIENTATION_ROT_90:
+        return 90;
+    case KEXIV_ORIENTATION_ROT_180:
+        return 280;
+    case KEXIV_ORIENTATION_ROT_270:
+        return 270;
+    default:
+        qCWarning(PluginsLog) << "KExiv2::ImageOrientation value " << orient << " not a pure rotation. Discarding orientation info.";
+        return 0;
     }
 }
 
-Plugins::ImageInfo::ImageInfo( KIPI::Interface* interface, const QUrl &url )
-    : KIPI::ImageInfoShared( interface, url )
+Plugins::ImageInfo::ImageInfo(KIPI::Interface *interface, const QUrl &url)
+    : KIPI::ImageInfoShared(interface, url)
 {
-    m_info = DB::ImageDB::instance()->info( DB::FileName::fromAbsolutePath(_url.path()));
+    m_info = DB::ImageDB::instance()->info(DB::FileName::fromAbsolutePath(_url.path()));
 }
 
-QMap<QString,QVariant> Plugins::ImageInfo::attributes()
+QMap<QString, QVariant> Plugins::ImageInfo::attributes()
 {
     if (m_info == nullptr) {
         // This can happen if we're trying to access an image that
         // has been deleted on-disc, but not yet the database
-        return QMap<QString,QVariant>();
+        return QMap<QString, QVariant>();
     }
 
-    Q_ASSERT( m_info );
-    QMap<QString,QVariant> res;
+    Q_ASSERT(m_info);
+    QMap<QString, QVariant> res;
 
     res.insert(QString::fromLatin1("name"), QFileInfo(m_info->fileName().absolute()).baseName());
     res.insert(QString::fromLatin1("comment"), m_info->description());
@@ -105,8 +105,8 @@ QMap<QString,QVariant> Plugins::ImageInfo::attributes()
     res.insert(QLatin1String("dateto"), m_info->date().end());
     res.insert(QLatin1String("isexactdate"), m_info->date().start() == m_info->date().end());
 
-    res.insert(QString::fromLatin1("orientation"), deg2KexivOrientation(m_info->angle()) );
-    res.insert(QString::fromLatin1("angle"), deg2KexivOrientation(m_info->angle()) ); // for compatibility with older versions. Now called orientation.
+    res.insert(QString::fromLatin1("orientation"), deg2KexivOrientation(m_info->angle()));
+    res.insert(QString::fromLatin1("angle"), deg2KexivOrientation(m_info->angle())); // for compatibility with older versions. Now called orientation.
 
     res.insert(QString::fromLatin1("title"), m_info->label());
 
@@ -122,7 +122,7 @@ QMap<QString,QVariant> Plugins::ImageInfo::attributes()
         res.insert(QString::fromLatin1("longitude"), QVariant(position.lon()));
         res.insert(QString::fromLatin1("latitude"), QVariant(position.lat()));
         if (position.hasAltitude())
-           res.insert(QString::fromLatin1("altitude"), QVariant(position.alt()));
+            res.insert(QString::fromLatin1("altitude"), QVariant(position.alt()));
     }
 #endif
 
@@ -131,26 +131,26 @@ QMap<QString,QVariant> Plugins::ImageInfo::attributes()
     QList<DB::CategoryPtr> categories = DB::ImageDB::instance()->categoryCollection()->categories();
     QStringList tags;
     QStringList tagspath;
-    const QLatin1String sep ("/");
-    Q_FOREACH( const DB::CategoryPtr category, categories ) {
+    const QLatin1String sep("/");
+    Q_FOREACH (const DB::CategoryPtr category, categories) {
         QString categoryName = category->name();
-        if ( category->isSpecialCategory() )
+        if (category->isSpecialCategory())
             continue;
         // I don't know why any categories except the above should be excluded
         //if ( category->doShow() ) {
-            Utilities::StringSet items = m_info->itemsOfCategory( categoryName );
-            Q_FOREACH( const QString &tag, items ) {
-                tags.append( tag );
-                // digikam compatible tag path:
-                // note: this produces a semi-flattened hierarchy.
-                // instead of "Places/France/Paris" this will yield "Places/Paris"
-                tagspath.append( categoryName + sep + tag );
-            }
+        Utilities::StringSet items = m_info->itemsOfCategory(categoryName);
+        Q_FOREACH (const QString &tag, items) {
+            tags.append(tag);
+            // digikam compatible tag path:
+            // note: this produces a semi-flattened hierarchy.
+            // instead of "Places/France/Paris" this will yield "Places/Paris"
+            tagspath.append(categoryName + sep + tag);
+        }
         //}
     }
-    res.insert(QString::fromLatin1( "tagspath" ), tagspath );
-    res.insert(QString::fromLatin1( "keywords" ), tags );
-    res.insert(QString::fromLatin1( "tags" ), tags ); // for compatibility with older versions. Now called keywords.
+    res.insert(QString::fromLatin1("tagspath"), tagspath);
+    res.insert(QString::fromLatin1("keywords"), tags);
+    res.insert(QString::fromLatin1("tags"), tags); // for compatibility with older versions. Now called keywords.
 
     // TODO: implement this:
     //res.insert(QString::fromLatin1( "filesize" ), xxx );
@@ -166,39 +166,37 @@ QMap<QString,QVariant> Plugins::ImageInfo::attributes()
 
 void Plugins::ImageInfo::clearAttributes()
 {
-    if( m_info ) {
+    if (m_info) {
         // official behaviour is to delete all officially supported attributes:
         QStringList attr;
-        attr.append( QString::fromLatin1("comment") );
-        attr.append( QString::fromLatin1("date") );
-        attr.append( QString::fromLatin1("title") );
-        attr.append( QString::fromLatin1("orientation") );
-        attr.append( QString::fromLatin1("tagspath") );
-        attr.append( QString::fromLatin1("rating") );
-        attr.append( QString::fromLatin1("colorlabel") );
-        attr.append( QString::fromLatin1("picklabel") );
-        attr.append( QString::fromLatin1("gpslocation") );
-        attr.append( QString::fromLatin1("copyrights") );
+        attr.append(QString::fromLatin1("comment"));
+        attr.append(QString::fromLatin1("date"));
+        attr.append(QString::fromLatin1("title"));
+        attr.append(QString::fromLatin1("orientation"));
+        attr.append(QString::fromLatin1("tagspath"));
+        attr.append(QString::fromLatin1("rating"));
+        attr.append(QString::fromLatin1("colorlabel"));
+        attr.append(QString::fromLatin1("picklabel"));
+        attr.append(QString::fromLatin1("gpslocation"));
+        attr.append(QString::fromLatin1("copyrights"));
         delAttributes(attr);
     }
 }
 
-void Plugins::ImageInfo::addAttributes( const QMap<QString,QVariant>& amap )
+void Plugins::ImageInfo::addAttributes(const QMap<QString, QVariant> &amap)
 {
-    if ( m_info && ! amap.empty() ) {
-        QMap<QString,QVariant> map = amap;
-        if ( map.contains(QLatin1String("name")) )
-        {
+    if (m_info && !amap.empty()) {
+        QMap<QString, QVariant> map = amap;
+        if (map.contains(QLatin1String("name"))) {
             // plugin renamed the item
             // TODO: implement this
             qCWarning(PluginsLog, "File renaming by kipi-plugin not supported.");
             //map.remove(QLatin1String("name"));
         }
-        if ( map.contains(QLatin1String("comment")) )
-        {
+        if (map.contains(QLatin1String("comment"))) {
             // is it save to do that? digikam seems to allow multiple comments on a single image
             // if a plugin assumes that it is adding a comment, not setting it, things might go badly...
-            m_info->setDescription( map[QLatin1String("comment")].toString() );
+            m_info->setDescription(map[QLatin1String("comment")].toString());
             map.remove(QLatin1String("comment"));
         }
         // note: this probably won't work as expected because according to the spec,
@@ -214,82 +212,69 @@ void Plugins::ImageInfo::addAttributes( const QMap<QString,QVariant>& amap )
             m_info->setDate(DB::ImageDate(map[QLatin1String("date")].toDateTime()));
             map.remove(QLatin1String("date"));
         }
-        if ( map.contains(QLatin1String("angle")) )
-        {
+        if (map.contains(QLatin1String("angle"))) {
             qCWarning(PluginsLog, "Kipi-plugin uses deprecated attribute \"angle\".");
-            m_info->setAngle( kexivOrientation2deg( map[QLatin1String("angle")].toInt() ) );
+            m_info->setAngle(kexivOrientation2deg(map[QLatin1String("angle")].toInt()));
             map.remove(QLatin1String("angle"));
         }
-        if ( map.contains(QLatin1String("orientation")) )
-        {
-            m_info->setAngle( kexivOrientation2deg( map[QLatin1String("orientation")].toInt() ) );
+        if (map.contains(QLatin1String("orientation"))) {
+            m_info->setAngle(kexivOrientation2deg(map[QLatin1String("orientation")].toInt()));
             map.remove(QLatin1String("orientation"));
         }
-        if ( map.contains(QLatin1String("title")) )
-        {
-            m_info->setLabel( map[QLatin1String("title")].toString() );
+        if (map.contains(QLatin1String("title"))) {
+            m_info->setLabel(map[QLatin1String("title")].toString());
             map.remove(QLatin1String("title"));
         }
-        if ( map.contains(QLatin1String("rating")) )
-        {
-            m_info->setRating( map[QLatin1String("rating")].toInt() );
+        if (map.contains(QLatin1String("rating"))) {
+            m_info->setRating(map[QLatin1String("rating")].toInt());
             map.remove(QLatin1String("rating"));
         }
-        if ( map.contains(QLatin1String("tagspath")) )
-        {
+        if (map.contains(QLatin1String("tagspath"))) {
             const QStringList tagspaths = map[QLatin1String("tagspath")].toStringList();
             const DB::CategoryCollection *categories = DB::ImageDB::instance()->categoryCollection();
             DB::MemberMap &memberMap = DB::ImageDB::instance()->memberMap();
-            Q_FOREACH( const QString &path, tagspaths )
-            {
+            Q_FOREACH (const QString &path, tagspaths) {
                 qCDebug(PluginsLog) << "Adding tags: " << path;
-                QStringList tagpath = path.split( QLatin1String("/"), QString::SkipEmptyParts );
+                QStringList tagpath = path.split(QLatin1String("/"), QString::SkipEmptyParts);
                 // Note: maybe tagspaths with only one component or with unknown first component
                 //  should be added to the "keywords"/"Events" category?
-                if ( tagpath.size() < 2 )
-                {
+                if (tagpath.size() < 2) {
                     qCWarning(PluginsLog) << "Ignoring incompatible tag: " << path;
                     continue;
                 }
 
                 // first component is the category,
                 const QString categoryName = tagpath.takeFirst();
-                DB::CategoryPtr cat = categories->categoryForName( categoryName );
-                if ( cat )
-                {
+                DB::CategoryPtr cat = categories->categoryForName(categoryName);
+                if (cat) {
                     QString previousTag;
                     // last component is the tag:
                     // others define hierarchy:
-                    Q_FOREACH( const QString &currentTag, tagpath )
-                    {
-                        if ( ! cat->items().contains( currentTag ) )
-                        {
+                    Q_FOREACH (const QString &currentTag, tagpath) {
+                        if (!cat->items().contains(currentTag)) {
                             qCDebug(PluginsLog) << "Adding tag " << currentTag << " to category " << categoryName;
                             // before we can use a tag, we have to add it
-                            cat->addItem( currentTag );
+                            cat->addItem(currentTag);
                         }
-                        if ( ! previousTag.isNull() )
-                        {
-                            if ( ! memberMap.isGroup( categoryName, previousTag ) )
-                            {
+                        if (!previousTag.isNull()) {
+                            if (!memberMap.isGroup(categoryName, previousTag)) {
                                 // create a group for the parent tag, so we can add a sub-category
-                                memberMap.addGroup(  categoryName, previousTag );
+                                memberMap.addGroup(categoryName, previousTag);
                             }
-                            if ( memberMap.canAddMemberToGroup( categoryName, previousTag, currentTag ) )
-                            {
+                            if (memberMap.canAddMemberToGroup(categoryName, previousTag, currentTag)) {
                                 // make currentTag a member of the previousTag group
-                                memberMap.addMemberToGroup( categoryName, previousTag, currentTag );
+                                memberMap.addMemberToGroup(categoryName, previousTag, currentTag);
                             } else {
                                 qCWarning(PluginsLog) << "Cannot make " << currentTag << " a subcategory of "
-                                    << categoryName << "/" << previousTag << "!";
+                                                      << categoryName << "/" << previousTag << "!";
                             }
                         }
                         previousTag = currentTag;
                     }
                     qCDebug(PluginsLog) << "Adding tag " << previousTag << " in category " << categoryName
-                        << " to image " << m_info->label();
+                                        << " to image " << m_info->label();
                     // previousTag must be a valid category (see addItem() above...)
-                    m_info->addCategoryInfo( categoryName, previousTag );
+                    m_info->addCategoryInfo(categoryName, previousTag);
                 } else {
                     qCWarning(PluginsLog) << "Unknown category: " << categoryName;
                 }
@@ -314,38 +299,32 @@ void Plugins::ImageInfo::addAttributes( const QMap<QString,QVariant>& amap )
         // source
 
         MainWindow::DirtyIndicator::markDirty();
-        if ( ! map.isEmpty() )
-        {
+        if (!map.isEmpty()) {
             qCWarning(PluginsLog) << "The following attributes are not (yet) supported by the KPhotoAlbum KIPI interface:" << map;
         }
     }
 }
 
-void Plugins::ImageInfo::delAttributes( const QStringList& attrs)
+void Plugins::ImageInfo::delAttributes(const QStringList &attrs)
 {
-    if ( m_info && ! attrs.empty() ) {
+    if (m_info && !attrs.empty()) {
         QStringList delAttrs = attrs;
-        if ( delAttrs.contains(QLatin1String("comment")))
-        {
-            m_info->setDescription( QString() );
+        if (delAttrs.contains(QLatin1String("comment"))) {
+            m_info->setDescription(QString());
             delAttrs.removeAll(QLatin1String("comment"));
         }
         // not supported: date
-        if ( delAttrs.contains(QLatin1String("orientation")) ||
-                delAttrs.contains(QLatin1String("angle")) )
-        {
-            m_info->setAngle( 0 );
+        if (delAttrs.contains(QLatin1String("orientation")) || delAttrs.contains(QLatin1String("angle"))) {
+            m_info->setAngle(0);
             delAttrs.removeAll(QLatin1String("orientation"));
             delAttrs.removeAll(QLatin1String("angle"));
         }
-        if ( delAttrs.contains(QLatin1String("rating")))
-        {
-            m_info->setRating( -1 );
+        if (delAttrs.contains(QLatin1String("rating"))) {
+            m_info->setRating(-1);
             delAttrs.removeAll(QLatin1String("rating"));
         }
-        if ( delAttrs.contains(QLatin1String("title")))
-        {
-            m_info->setLabel( QString() );
+        if (delAttrs.contains(QLatin1String("title"))) {
+            m_info->setLabel(QString());
             delAttrs.removeAll(QLatin1String("title"));
         }
         // TODO:
@@ -353,27 +332,24 @@ void Plugins::ImageInfo::delAttributes( const QStringList& attrs)
         // (picklabel)
         // copyrights
         // not supported: gpslocation
-        if ( delAttrs.contains(QLatin1String("tags")) ||
-                delAttrs.contains(QLatin1String("tagspath")))
-        {
+        if (delAttrs.contains(QLatin1String("tags")) || delAttrs.contains(QLatin1String("tagspath"))) {
             m_info->clearAllCategoryInfo();
             delAttrs.removeAll(QLatin1String("tags"));
             delAttrs.removeAll(QLatin1String("tagspath"));
         }
         MainWindow::DirtyIndicator::markDirty();
-        if ( ! delAttrs.isEmpty() )
-        {
+        if (!delAttrs.isEmpty()) {
             qCWarning(PluginsLog) << "The following attributes are not (yet) supported by the KPhotoAlbum KIPI interface:" << delAttrs;
         }
     }
 }
 
-void Plugins::ImageInfo::cloneData( ImageInfoShared* const other )
+void Plugins::ImageInfo::cloneData(ImageInfoShared *const other)
 {
-    ImageInfoShared::cloneData( other );
-    if ( m_info ) {
-        Plugins::ImageInfo* inf = static_cast<Plugins::ImageInfo*>( other );
-        m_info->setDate( inf->m_info->date() );
+    ImageInfoShared::cloneData(other);
+    if (m_info) {
+        Plugins::ImageInfo *inf = static_cast<Plugins::ImageInfo *>(other);
+        m_info->setDate(inf->m_info->date());
         MainWindow::DirtyIndicator::markDirty();
     }
 }
