@@ -18,14 +18,16 @@
 */
 
 #include "UploadImageCollection.h"
+
 #include <Settings/SettingsData.h>
 
 #include <KLocalizedString>
 
-namespace Plugins {
+namespace Plugins
+{
 
-UploadImageCollection::UploadImageCollection(const QString& path)
-    :m_path(path)
+UploadImageCollection::UploadImageCollection(const QString &path)
+    : m_path(path)
 {
 }
 
@@ -46,7 +48,7 @@ QUrl UploadImageCollection::uploadUrl()
 
 QUrl UploadImageCollection::uploadRootUrl()
 {
-    QUrl url = QUrl::fromLocalFile(Settings::SettingsData::instance()->imageDirectory() );
+    QUrl url = QUrl::fromLocalFile(Settings::SettingsData::instance()->imageDirectory());
     return url;
 }
 
