@@ -21,10 +21,12 @@
 
 #include "ImageNameStore.h"
 #include "RemoteCommand.h"
-#include "DB/ImageSearchInfo.h"
-#include <QObject>
+
+#include <DB/ImageSearchInfo.h>
+#include <ImageManager/ImageClientInterface.h>
+
 #include <QHostAddress>
-#include "ImageManager/ImageClientInterface.h"
+#include <QObject>
 
 class QHostAddress;
 
@@ -36,15 +38,15 @@ class RemoteInterface : public QObject, public ImageManager::ImageClientInterfac
 {
     Q_OBJECT
 public:
-    static RemoteInterface& instance();
-    void pixmapLoaded(ImageManager::ImageRequest* request, const QImage& image) override;
-    bool requestStillNeeded(const DB::FileName& fileName);
-    void listen(QHostAddress address=QHostAddress::Any);
+    static RemoteInterface &instance();
+    void pixmapLoaded(ImageManager::ImageRequest *request, const QImage &image) override;
+    bool requestStillNeeded(const DB::FileName &fileName);
+    void listen(QHostAddress address = QHostAddress::Any);
     void stopListening();
-    void connectTo(const QHostAddress& address);
+    void connectTo(const QHostAddress &address);
 
 private slots:
-    void handleCommand(const RemoteCommand&);
+    void handleCommand(const RemoteCommand &);
 
 signals:
     void connected();
@@ -55,17 +57,17 @@ signals:
 private:
     explicit RemoteInterface(QObject *parent = 0);
 
-    void sendCategoryNames(const SearchRequest& searchInfo);
-    void sendCategoryValues(const SearchRequest& search);
-    void sendImageSearchResult(const SearchInfo& search);
-    void requestThumbnail(const ThumbnailRequest& command);
-    void cancelRequest(const ThumbnailCancelRequest& command);
-    void sendImageDetails(const ImageDetailsRequest& command);
-    void sendHomePageImages(const StaticImageRequest& command);
-    void setToken(const ToggleTokenRequest& command);
+    void sendCategoryNames(const SearchRequest &searchInfo);
+    void sendCategoryValues(const SearchRequest &search);
+    void sendImageSearchResult(const SearchInfo &search);
+    void requestThumbnail(const ThumbnailRequest &command);
+    void cancelRequest(const ThumbnailCancelRequest &command);
+    void sendImageDetails(const ImageDetailsRequest &command);
+    void sendHomePageImages(const StaticImageRequest &command);
+    void setToken(const ToggleTokenRequest &command);
 
-    DB::ImageSearchInfo convert(const RemoteControl::SearchInfo&) const;
-    Server* m_connection;
+    DB::ImageSearchInfo convert(const RemoteControl::SearchInfo &) const;
+    Server *m_connection;
     QSet<DB::FileName> m_activeReuqest;
     ImageNameStore m_imageNameStore;
 };
