@@ -20,23 +20,26 @@
 #include <QComboBox>
 #include <QWidget>
 
-namespace Exif { class TreeView; }
+namespace Exif
+{
+class TreeView;
+}
 
 namespace Settings
 {
 class SettingsData;
 
-class ExifPage :public QWidget
+class ExifPage : public QWidget
 {
 public:
-    explicit ExifPage( QWidget* parent );
-    void loadSettings( Settings::SettingsData* );
-    void saveSettings( Settings::SettingsData* );
+    explicit ExifPage(QWidget *parent);
+    void loadSettings(Settings::SettingsData *);
+    void saveSettings(Settings::SettingsData *);
 
 private:
-    Exif::TreeView* m_exifForViewer;
-    Exif::TreeView* m_exifForDialog;
-    QComboBox* m_iptcCharset;
+    Exif::TreeView *m_exifForViewer;
+    Exif::TreeView *m_exifForDialog;
+    QComboBox *m_iptcCharset;
 };
 
 }
