@@ -25,32 +25,32 @@ class QCheckBox;
 class KComboBox;
 class QSpinBox;
 class QDoubleSpinBox;
-namespace Settings {
+namespace Settings
+{
 class SettingsData;
 
-class ThumbnailsPage :public QWidget
+class ThumbnailsPage : public QWidget
 {
 public:
-    explicit ThumbnailsPage( QWidget* parent );
-    void loadSettings( Settings::SettingsData* );
-    void saveSettings( Settings::SettingsData* );
+    explicit ThumbnailsPage(QWidget *parent);
+    void loadSettings(Settings::SettingsData *);
+    void saveSettings(Settings::SettingsData *);
 
 private:
-    QSpinBox* m_previewSize;
-    QSpinBox* m_thumbnailSize;
-    KComboBox* m_thumbnailAspectRatio;
-    QSpinBox* m_thumbnailSpace;
-    QCheckBox* m_thumbnailDisplayGrid;
-    QCheckBox* m_displayLabels;
-    QCheckBox* m_displayCategories;
-    QSpinBox* m_autoShowThumbnailView;
-    KColorButton* m_backgroundColor;
-    QCheckBox* m_incrementalThumbnails;
+    QSpinBox *m_previewSize;
+    QSpinBox *m_thumbnailSize;
+    KComboBox *m_thumbnailAspectRatio;
+    QSpinBox *m_thumbnailSpace;
+    QCheckBox *m_thumbnailDisplayGrid;
+    QCheckBox *m_displayLabels;
+    QCheckBox *m_displayCategories;
+    QSpinBox *m_autoShowThumbnailView;
+    KColorButton *m_backgroundColor;
+    QCheckBox *m_incrementalThumbnails;
 };
 
 }
 
-
 #endif /* THUMBNAILSPAGE_H */
 
 // vi:expandtab:tabstop=4 shiftwidth=4:
