@@ -1,4 +1,4 @@
-/* Copyright (C) 2003-2010 Jesper K. Pedersen <blackie@kde.org>
+/* Copyright (C) 2003-2019 The KPhotoAlbum Development Team
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -16,26 +16,30 @@
    Boston, MA 02110-1301, USA.
 */
 #include "ThumbnailFacade.h"
-#include "ImageManager/ThumbnailCache.h"
-#include <BackgroundJobs/HandleVideoThumbnailRequestJob.h>
 
-#include "Settings/SettingsData.h"
-#include "ThumbnailToolTip.h"
-#include "ThumbnailModel.h"
 #include "CellGeometry.h"
-#include "ThumbnailWidget.h"
+#include "FilterWidget.h"
 #include "GridResizeSlider.h"
+#include "ThumbnailModel.h"
+#include "ThumbnailToolTip.h"
+#include "ThumbnailWidget.h"
 
-ThumbnailView::ThumbnailFacade* ThumbnailView::ThumbnailFacade::s_instance = nullptr;
+#include <BackgroundJobs/HandleVideoThumbnailRequestJob.h>
+#include <ImageManager/ThumbnailCache.h>
+#include <Settings/SettingsData.h>
+
+ThumbnailView::ThumbnailFacade *ThumbnailView::ThumbnailFacade::s_instance = nullptr;
 ThumbnailView::ThumbnailFacade::ThumbnailFacade()
-    :m_cellGeometry( nullptr ),
-     m_model( nullptr ),m_widget( nullptr ), m_toolTip( nullptr )
+    : m_cellGeometry(nullptr)
+    , m_model(nullptr)
+    , m_widget(nullptr)
+    , m_toolTip(nullptr)
 {
     // To avoid one of the components references one of the other before it has been initialized, we first construct them all with null.
     m_cellGeometry = new CellGeometry(this);
     m_model = new ThumbnailModel(this);
     m_widget = new ThumbnailWidget(this);
-    m_toolTip = new ThumbnailToolTip( m_widget );
+    m_toolTip = new ThumbnailToolTip(m_widget);
 
     connect(m_widget, &ThumbnailWidget::showImage, this, &ThumbnailFacade::showImage);
     connect(m_widget, &ThumbnailWidget::showSelection, this, &ThumbnailFacade::showSelection);
@@ -48,27 +52,27 @@ ThumbnailView::ThumbnailFacade::ThumbnailFacade()
     s_instance = this;
 }
 
-QWidget* ThumbnailView::ThumbnailFacade::gui()
+QWidget *ThumbnailView::ThumbnailFacade::gui()
 {
     return m_widget;
 }
 
-void ThumbnailView::ThumbnailFacade::gotoDate( const DB::ImageDate& date, bool b)
+void ThumbnailView::ThumbnailFacade::gotoDate(const DB::ImageDate &date, bool b)
 {
-    m_widget->gotoDate( date, b );
+    m_widget->gotoDate(date, b);
 }
 
-void ThumbnailView::ThumbnailFacade::setCurrentItem( const DB::FileName& fileName )
+void ThumbnailView::ThumbnailFacade::setCurrentItem(const DB::FileName &fileName)
 {
     widget()->setCurrentItem(fileName);
 }
 
-void ThumbnailView::ThumbnailFacade::reload( SelectionUpdateMethod method )
+void ThumbnailView::ThumbnailFacade::reload(SelectionUpdateMethod method)
 {
-    m_widget->reload( method );
+    m_widget->reload(method);
 }
 
-DB::FileNameList ThumbnailView::ThumbnailFacade::selection( ThumbnailView::SelectionMode mode ) const
+DB::FileNameList ThumbnailView::ThumbnailFacade::selection(ThumbnailView::SelectionMode mode) const
 {
     return m_widget->selection(mode);
 }
@@ -88,19 +92,29 @@ DB::FileName ThumbnailView::ThumbnailFacade::currentItem() const
     return m_model->imageAt(m_widget->currentIndex().row());
 }
 
-void ThumbnailView::ThumbnailFacade::setImageList(const DB::FileNameList& list)
+void ThumbnailView::ThumbnailFacade::setImageList(const DB::FileNameList &list)
 {
     m_model->setImageList(list);
 }
 
-void ThumbnailView::ThumbnailFacade::setSortDirection( SortDirection direction )
+void ThumbnailView::ThumbnailFacade::setSortDirection(SortDirection direction)
 {
-    m_model->setSortDirection( direction );
+    m_model->setSortDirection(direction);
 }
 
-QSlider* ThumbnailView::ThumbnailFacade::createResizeSlider()
+QSlider *ThumbnailView::ThumbnailFacade::createResizeSlider()
 {
-    return new GridResizeSlider( this );
+    return new GridResizeSlider(this);
+}
+
+ThumbnailView::FilterWidget *ThumbnailView::ThumbnailFacade::filterWidget()
+{
+    return model()->filterWidget();
+}
+
+KActionCollection *ThumbnailView::ThumbnailFacade::actions()
+{
+    return filterWidget()->actions();
 }
 
 void ThumbnailView::ThumbnailFacade::selectAll()
@@ -113,12 +127,12 @@ void ThumbnailView::ThumbnailFacade::clearSelection()
     m_widget->clearSelection();
 }
 
-void ThumbnailView::ThumbnailFacade::showToolTipsOnImages( bool on )
+void ThumbnailView::ThumbnailFacade::showToolTipsOnImages(bool on)
 {
-    m_toolTip->setActive( on );
+    m_toolTip->setActive(on);
 }
 
-void ThumbnailView::ThumbnailFacade::toggleStackExpansion(const DB::FileName& fileName)
+void ThumbnailView::ThumbnailFacade::toggleStackExpansion(const DB::FileName &fileName)
 {
     m_model->toggleStackExpansion(fileName);
 }
@@ -138,43 +152,48 @@ void ThumbnailView::ThumbnailFacade::updateDisplayModel()
     m_model->updateDisplayModel();
 }
 
-void ThumbnailView::ThumbnailFacade::changeSingleSelection(const DB::FileName& fileName)
+void ThumbnailView::ThumbnailFacade::changeSingleSelection(const DB::FileName &fileName)
 {
     m_widget->changeSingleSelection(fileName);
 }
 
-ThumbnailView::ThumbnailModel* ThumbnailView::ThumbnailFacade::model()
+ThumbnailView::ThumbnailModel *ThumbnailView::ThumbnailFacade::model()
 {
-    Q_ASSERT( m_model );
+    Q_ASSERT(m_model);
     return m_model;
 }
 
-
-ThumbnailView::CellGeometry* ThumbnailView::ThumbnailFacade::cellGeometry()
+ThumbnailView::CellGeometry *ThumbnailView::ThumbnailFacade::cellGeometry()
 {
-    Q_ASSERT( m_cellGeometry );
+    Q_ASSERT(m_cellGeometry);
     return m_cellGeometry;
 }
 
-ThumbnailView::ThumbnailWidget* ThumbnailView::ThumbnailFacade::widget()
+ThumbnailView::ThumbnailWidget *ThumbnailView::ThumbnailFacade::widget()
 {
-    Q_ASSERT( m_widget );
+    Q_ASSERT(m_widget);
     return m_widget;
 }
 
-ThumbnailView::ThumbnailFacade* ThumbnailView::ThumbnailFacade::instance()
+ThumbnailView::ThumbnailFacade *ThumbnailView::ThumbnailFacade::instance()
 {
-    Q_ASSERT( s_instance );
+    Q_ASSERT(s_instance);
     return s_instance;
 }
 
 void ThumbnailView::ThumbnailFacade::slotRecreateThumbnail()
 {
-    Q_FOREACH( const DB::FileName& fileName, widget()->selection( NoExpandCollapsedStacks )) {
-        ImageManager::ThumbnailCache::instance()->removeThumbnail( fileName );
+    Q_FOREACH (const DB::FileName &fileName, widget()->selection(NoExpandCollapsedStacks)) {
+        ImageManager::ThumbnailCache::instance()->removeThumbnail(fileName);
         BackgroundJobs::HandleVideoThumbnailRequestJob::removeFullScaleFrame(fileName);
         m_model->updateCell(fileName);
     }
 }
 
+void ThumbnailView::ThumbnailFacade::clearFilter()
+{
+    Q_ASSERT(m_model);
+    m_model->clearFilter();
+}
+
 // vi:expandtab:tabstop=4 shiftwidth=4:
