@@ -16,16 +16,19 @@
    Boston, MA 02110-1301, USA.
 */
 #include "ThumbnailRequest.h"
+
 #include "ThumbnailModel.h"
 
-ThumbnailView::ThumbnailRequest::ThumbnailRequest( int row, const DB::FileName& fileName, const QSize& size, int angle, ThumbnailModel* client)
-    : ImageManager::ImageRequest( fileName, size, angle, client ), m_thumbnailModel( client ), m_row(row)
+ThumbnailView::ThumbnailRequest::ThumbnailRequest(int row, const DB::FileName &fileName, const QSize &size, int angle, ThumbnailModel *client)
+    : ImageManager::ImageRequest(fileName, size, angle, client)
+    , m_thumbnailModel(client)
+    , m_row(row)
 {
     setIsThumbnailRequest(true);
 }
 
 bool ThumbnailView::ThumbnailRequest::stillNeeded() const
 {
-    return m_thumbnailModel->thumbnailStillNeeded( m_row );
+    return m_thumbnailModel->thumbnailStillNeeded(m_row);
 }
 // vi:expandtab:tabstop=4 shiftwidth=4:
