@@ -18,18 +18,17 @@
 
 #ifndef VIDEO_UTIL_H
 #define VIDEO_UTIL_H
-#include "DB/FileName.h"
+#include <DB/FileName.h>
 
 #include <QSet>
 #include <QString>
 
 namespace Utilities
 {
-const QSet<QString>& supportedVideoExtensions();
-bool isVideo( const DB::FileName& fileName );
+const QSet<QString> &supportedVideoExtensions();
+bool isVideo(const DB::FileName &fileName);
 }
 
-
 #endif /* VIDEO_UTIL_H */
 
 // vi:expandtab:tabstop=4 shiftwidth=4:
