@@ -18,6 +18,15 @@
 
 #include "CategoryImageConfig.h"
 
+#include <DB/CategoryCollection.h>
+#include <DB/ImageDB.h>
+#include <DB/ImageInfo.h>
+#include <DB/MemberMap.h>
+#include <Settings/SettingsData.h>
+#include <Utilities/FileUtil.h>
+
+#include <KComboBox>
+#include <KLocalizedString>
 #include <QDialogButtonBox>
 #include <QGridLayout>
 #include <QLabel>
@@ -27,62 +36,52 @@
 #include <QPushButton>
 #include <QVBoxLayout>
 
-#include <KComboBox>
-#include <KLocalizedString>
-
-#include <DB/CategoryCollection.h>
-#include <DB/ImageDB.h>
-#include <DB/ImageInfo.h>
-#include <DB/MemberMap.h>
-#include <Settings/SettingsData.h>
-#include <Utilities/FileUtil.h>
-
 using Utilities::StringSet;
 
-Viewer::CategoryImageConfig* Viewer::CategoryImageConfig::s_instance = nullptr;
+Viewer::CategoryImageConfig *Viewer::CategoryImageConfig::s_instance = nullptr;
 
 Viewer::CategoryImageConfig::CategoryImageConfig()
-    : m_image( QImage() )
+    : m_image(QImage())
 {
-    setWindowTitle( i18nc("@title:window","Configure Category Image") );
-    QWidget* top = new QWidget;
+    setWindowTitle(i18nc("@title:window", "Configure Category Image"));
+    QWidget *top = new QWidget;
 
-    QVBoxLayout* lay1 = new QVBoxLayout( top );
+    QVBoxLayout *lay1 = new QVBoxLayout(top);
     setLayout(lay1);
-    QGridLayout* lay2 = new QGridLayout;
-    lay1->addLayout( lay2 );
+    QGridLayout *lay2 = new QGridLayout;
+    lay1->addLayout(lay2);
 
     // Group
-    QLabel* label = new QLabel( i18nc("@label:listbox As in 'select the tag category'","Category:" ), top );
-    lay2->addWidget( label, 0, 0 );
-    m_group = new KComboBox( top );
-    lay2->addWidget( m_group, 0, 1 );
+    QLabel *label = new QLabel(i18nc("@label:listbox As in 'select the tag category'", "Category:"), top);
+    lay2->addWidget(label, 0, 0);
+    m_group = new KComboBox(top);
+    lay2->addWidget(m_group, 0, 1);
     connect(m_group, static_cast<void (QComboBox::*)(int)>(&QComboBox::activated), this, &CategoryImageConfig::groupChanged);
 
     // Member
-    label = new QLabel( i18nc("@label:listbox As in 'select a tag'", "Tag:" ), top );
-    lay2->addWidget( label, 1, 0 );
-    m_member = new KComboBox( top );
-    lay2->addWidget( m_member, 1, 1 );
+    label = new QLabel(i18nc("@label:listbox As in 'select a tag'", "Tag:"), top);
+    lay2->addWidget(label, 1, 0);
+    m_member = new KComboBox(top);
+    lay2->addWidget(m_member, 1, 1);
     connect(m_member, static_cast<void (QComboBox::*)(int)>(&QComboBox::activated), this, &CategoryImageConfig::memberChanged);
 
     // Current Value
-    QGridLayout* lay3 = new QGridLayout;
-    lay1->addLayout( lay3 );
-    label = new QLabel( i18nc("@label The current category image","Current image:"), top );
-    lay3->addWidget( label, 0, 0 );
+    QGridLayout *lay3 = new QGridLayout;
+    lay1->addLayout(lay3);
+    label = new QLabel(i18nc("@label The current category image", "Current image:"), top);
+    lay3->addWidget(label, 0, 0);
 
-    m_current = new QLabel( top );
-    m_current->setFixedSize( 128, 128 );
-    lay3->addWidget( m_current, 0, 1 );
+    m_current = new QLabel(top);
+    m_current->setFixedSize(128, 128);
+    lay3->addWidget(m_current, 0, 1);
 
     // New Value
-    m_imageLabel = new QLabel( i18nc("@label Preview of the new category imape", "New image:"), top );
-    lay3->addWidget( m_imageLabel, 1, 0 );
+    m_imageLabel = new QLabel(i18nc("@label Preview of the new category imape", "New image:"), top);
+    lay3->addWidget(m_imageLabel, 1, 0);
 
-    m_imageLabel = new QLabel( top );
-    m_imageLabel->setFixedSize( 128, 128 );
-    lay3->addWidget( m_imageLabel, 1, 1 );
+    m_imageLabel = new QLabel(top);
+    m_imageLabel->setFixedSize(128, 128);
+    lay3->addWidget(m_imageLabel, 1, 1);
 
     QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Close);
     QPushButton *user1Button = new QPushButton;
@@ -105,20 +104,19 @@ void Viewer::CategoryImageConfig::groupChanged()
     StringSet directMembers = m_info->itemsOfCategory(categoryName);
 
     StringSet set = directMembers;
-    QMap<QString,StringSet> map =
-        DB::ImageDB::instance()->memberMap().inverseMap(categoryName);
-    for( StringSet::const_iterator directMembersIt = directMembers.begin();
-         directMembersIt != directMembers.end(); ++directMembersIt ) {
+    QMap<QString, StringSet> map = DB::ImageDB::instance()->memberMap().inverseMap(categoryName);
+    for (StringSet::const_iterator directMembersIt = directMembers.begin();
+         directMembersIt != directMembers.end(); ++directMembersIt) {
         set += map[*directMembersIt];
     }
 
     QStringList list = set.toList();
 
     list.sort();
-    m_member->addItems( list );
-    int index = list.indexOf( currentText );
-    if ( index != -1 )
-        m_member->setCurrentIndex( index );
+    m_member->addItems(list);
+    int index = list.indexOf(currentText);
+    if (index != -1)
+        m_member->setCurrentIndex(index);
 
     memberChanged();
 }
@@ -128,10 +126,8 @@ void Viewer::CategoryImageConfig::memberChanged()
     QString categoryName = currentGroup();
     if (categoryName.isNull())
         return;
-    QPixmap pix =
-        DB::ImageDB::instance()->categoryCollection()->categoryForName( categoryName )->
-        categoryImage(categoryName, m_member->currentText(), 128, 128);
-    m_current->setPixmap( pix );
+    QPixmap pix = DB::ImageDB::instance()->categoryCollection()->categoryForName(categoryName)->categoryImage(categoryName, m_member->currentText(), 128, 128);
+    m_current->setPixmap(pix);
 }
 
 void Viewer::CategoryImageConfig::slotSet()
@@ -139,8 +135,7 @@ void Viewer::CategoryImageConfig::slotSet()
     QString categoryName = currentGroup();
     if (categoryName.isNull())
         return;
-    DB::ImageDB::instance()->categoryCollection()->categoryForName( categoryName )->
-        setCategoryImage(categoryName, m_member->currentText(), m_image);
+    DB::ImageDB::instance()->categoryCollection()->categoryForName(categoryName)->setCategoryImage(categoryName, m_member->currentText(), m_image);
     memberChanged();
 }
 
@@ -152,17 +147,17 @@ QString Viewer::CategoryImageConfig::currentGroup()
     return m_categoryNames[index];
 }
 
-void Viewer::CategoryImageConfig::setCurrentImage( const QImage& image, const DB::ImageInfoPtr& info )
+void Viewer::CategoryImageConfig::setCurrentImage(const QImage &image, const DB::ImageInfoPtr &info)
 {
     m_image = image;
-    m_imageLabel->setPixmap( QPixmap::fromImage(image) );
+    m_imageLabel->setPixmap(QPixmap::fromImage(image));
     m_info = info;
     groupChanged();
 }
 
-Viewer::CategoryImageConfig* Viewer::CategoryImageConfig::instance()
+Viewer::CategoryImageConfig *Viewer::CategoryImageConfig::instance()
 {
-    if ( !s_instance )
+    if (!s_instance)
         s_instance = new CategoryImageConfig();
     return s_instance;
 }
@@ -172,11 +167,11 @@ void Viewer::CategoryImageConfig::show()
     QString currentCategory = m_group->currentText();
     m_group->clear();
     m_categoryNames.clear();
-     QList<DB::CategoryPtr> categories = DB::ImageDB::instance()->categoryCollection()->categories();
+    QList<DB::CategoryPtr> categories = DB::ImageDB::instance()->categoryCollection()->categories();
     int index = 0;
     int currentIndex = -1;
-     for ( QList<DB::CategoryPtr>::ConstIterator categoryIt = categories.constBegin(); categoryIt != categories.constEnd(); ++categoryIt ) {
-        if ( !(*categoryIt)->isSpecialCategory() ) {
+    for (QList<DB::CategoryPtr>::ConstIterator categoryIt = categories.constBegin(); categoryIt != categories.constEnd(); ++categoryIt) {
+        if (!(*categoryIt)->isSpecialCategory()) {
             m_group->addItem((*categoryIt)->name());
             m_categoryNames.push_back((*categoryIt)->name());
             if ((*categoryIt)->name() == currentCategory)
@@ -185,11 +180,10 @@ void Viewer::CategoryImageConfig::show()
         }
     }
 
-    if ( currentIndex != -1 )
-        m_group->setCurrentIndex( currentIndex );
+    if (currentIndex != -1)
+        m_group->setCurrentIndex(currentIndex);
     groupChanged();
 
-
     QDialog::show();
 }
 
