@@ -19,10 +19,12 @@
 #ifndef VIDEOSHOOTER_H
 #define VIDEOSHOOTER_H
 
-#include <QObject>
 #include <DB/ImageInfoPtr.h>
 
-namespace Viewer {
+#include <QObject>
+
+namespace Viewer
+{
 class ViewerWidget;
 
 class VideoShooter : public QObject
@@ -30,16 +32,16 @@ class VideoShooter : public QObject
     Q_OBJECT
 
 public:
-    static void go( const DB::ImageInfoPtr& info, Viewer::ViewerWidget* viewer);
+    static void go(const DB::ImageInfoPtr &info, Viewer::ViewerWidget *viewer);
 
 private slots:
-    void start(const DB::ImageInfoPtr& info, ViewerWidget*);
+    void start(const DB::ImageInfoPtr &info, ViewerWidget *);
     void doShoot();
 
 private:
-    static VideoShooter* s_instance;
+    static VideoShooter *s_instance;
     explicit VideoShooter();
-    ViewerWidget* m_viewer;
+    ViewerWidget *m_viewer;
     bool m_infoboxVisible;
     DB::ImageInfoPtr m_info;
     bool m_wasPlaying;
