@@ -19,19 +19,28 @@
 #ifndef XMLREADER_H
 #define XMLREADER_H
 
-#include <QXmlStreamReader>
 #include <QSharedPointer>
+#include <QXmlStreamReader>
 
-namespace DB {
+namespace DB
+{
 class UIDelegate;
 }
 
-namespace XMLDB {
+namespace XMLDB
+{
 
 struct ElementInfo {
-    ElementInfo(bool isStartToken, const QString& tokenName )
-        : isValid(true), isStartToken(isStartToken),tokenName(tokenName) {}
-    ElementInfo() : isValid(false) {}
+    ElementInfo(bool isStartToken, const QString &tokenName)
+        : isValid(true)
+        , isStartToken(isStartToken)
+        , tokenName(tokenName)
+    {
+    }
+    ElementInfo()
+        : isValid(false)
+    {
+    }
 
     bool isValid;
     bool isStartToken;
@@ -41,9 +50,14 @@ struct ElementInfo {
 class XmlReader : public QXmlStreamReader
 {
 public:
-    explicit XmlReader(DB::UIDelegate &ui);
+    /**
+     * @brief XmlReader
+     * @param ui the UIDelegate for error messages
+     * @param friendlyStreamName a stream/file name to be displayed in messages
+     */
+    explicit XmlReader(DB::UIDelegate &ui, const QString &friendlyStreamName);
 
-    QString attribute(const QString &name, const QString& defaultValue = QString() );
+    QString attribute(const QString &name, const QString &defaultValue = QString());
     ElementInfo readNextStartOrStopElement(const QString &expectedStart);
     /**
      * Read the next element and ensure that it's an EndElement.
@@ -54,17 +68,18 @@ public:
      * @param readNextElement if set to false, don't read the next element.
      */
     void readEndElement(bool readNextElement = true);
-    bool hasAttribute(const QString& name);
+    bool hasAttribute(const QString &name);
     ElementInfo peekNext();
-    [[noreturn]] void complainStartElementExpected(const QString& name);
+    [[noreturn]] void complainStartElementExpected(const QString &name);
 
 private:
-    [[noreturn]] void reportError(const QString&);
+    [[noreturn]] void reportError(const QString &);
     QString tokenToString(TokenType);
     TokenType readNextInternal();
 
     DB::UIDelegate &m_ui;
     ElementInfo m_peek;
+    const QString m_streamName;
 };
 
 typedef QSharedPointer<XmlReader> ReaderPtr;
